# This function is written by Sirus Dehdari (sirus.dehdari@ne.su.se), PhD candidate
# in Economics at Stockholm University and visiting scholar at Harvard University.
# Latest version: 05/04/2015

# (This function uses another function for calculating the optimal bandwidth. See below
# for more information.)

### This estimates the treatment effect in a Regression Discontinuity Design -- with or
### without controls -- for a chosen bandwidth. The output is then presented in two
### matrices: one with estimates of the slope coefficient and standard errors, t-values
### and p-values, only for the treatment variable (which is a dummy for x > c), and the
### one matrix with results for treatment and controls (not for potential linear term),
### the idea is to give you one matrix with all the resuls for a number of different
### specifications that are allowed to differ in terms of bandwidth, inclusion of
### controls and linear/no linear term. For now, category control variables 
### cannot added, something that I will change in the future.

### This function allows for standard error correction using White's robust standard
### errors (hc0) or Conley standard errors. Makes sure to also load my functions for
### standard errors, as it is used for all different corrections (and even for 
### no correction).

### For now, it is important that the running variable is already centered
### around zero. I will update the function so that one instead sets the cut-off
### value and the running variable will then be centered in the function.

### Notice that you need the package corpcor

### Arguments
### - dep: name of the dependent variable
### - fdata: your data set
### - band: bandwidth, in whatever metric the running variable is in. For the optimal bandwidth based
###   on Imbens & Kalyanaraman (2011), write "ik", and "ik/2" for half this bandwidth. 
###   This argument also determines the number of specifications in the table.
### - C_k: This constant is used when calculating the optimal bandwidth and default is set at 5.40 for
###   a uniform kernel.
### - linterm: option ("yes"/"no") to add a linear term of the running variable (allowed to differ on
###   each side of the cut-off). You need to specify one input for each specification.
### - se: standard error correction ("hc0/"conley"/"none"). Default is set at "none"
###   which gives you standard errors under homoskedasticity. For now, all specifications
###   will have the same correction. Notice that lon, lat, coord, and threshold also 
###   need to be specified for "conley". 
### - run: name of the running variable, same for all specifications
### - control: A list of the control variable(s) for each specification. Default is set 
###   at no controls ("no"). To let some of the specifications have no controls, write
###   "none". A blank space ("") will be added to the cells in the table for the
###   controls that are excluded from some specifications.
### - infer: determines how to display inferens as standard errors and stars on 
###   coefficients ("se"), t-values ("t"), or p-values ("p"). Default is "se".
### - round: determines decimals for rounding. Default is 3.
### - lon/lat: for Conley standard error, coordinates are needed, either in kilometer.
###   or in degrees. If you're not using Conley standard errors, do not specify anything.
### - coord: coordinates of lon/lat, either in "km" (kilometers), or decimal degrees (dd).
###   Default is "km".
### - threshold: the threshold for Conley standard errors. Default is set at 5.
### - show.controls: Set this to "yes" if you want to show all controls in the table, "no" if
###   you only want to show the coefficient for the treatment dummy. If "no", a 

##### THE FUNCTION BEGINS HERE
library(corpcor)
rddxtab <- function(dep, fdata, band, C_k = 5.40, poly = 0, se = "none", run, 
           control = "no", infer = "se", round = 3, lon = "none", lat = "none", 
           coord = "km", threshold = 5, cluster = "none", show.controls = "yes"){
  ### Saving number of specifications, and saving the dependent and the running     
  ### variable
  no.col <- length(band)
  y <- fdata[, dep]
  running <- fdata[,run]
  ### Creating a treatment dummy 1[x>0], and a treatment-running variable interaction
  treat <- running
  treat[treat>0] <- 1
  treat[treat<0] <- 0
  runtreat <- running*treat
  run2 <- running^2
  run3 <- running^3
  run2treat <- run2*treat
  run3treat <- run3*treat
  
  ### Saving the longitud and latitud coordinates (if specified
  if (lon != "none"){
    long <- fdata[,lon]
    lati <- fdata[,lat]
  }
  if (lon == "none"){
    long <- rep(1,dim(fdata)[1])
    lati <- rep(1,dim(fdata)[1])
  }
  ### If controls are added to any of the specifications, a list with the name of all
  ### the different controls is created, and their number is saved. Furthermore, each
  ### control is assigned a number (position) based on order of appearance
  if (control[[1]][1] != "no"){
    totcontrol <- unique(unlist(control[1:length(control)]))
    totcontrol <- totcontrol[totcontrol != "none"]
    no.totcont <- length(totcontrol)
    controlpos <- data.frame(totcontrol,as.numeric(1:no.totcont))
    con <- "yes"
  }
  ### If no controls are added at all, number of controls is set to 0
  if (control[[1]][1] == "no"){
    no.totcont <- 0
    control <- rep("none",no.col)
    con <- "no"
  }
  ### Saving an expression for the rounding (based on "round")
  rr <- as.character(round)
  spr <- paste(c("%.",rr,"f"), collapse="")
  
  ### Creating a matrix for the results on the treatment variable, and a matrix
  ### for xtable. Number of rows in textable is based on the total number of controls,
  ### and to this two rows are added for the treatment (estimated coefficient and sd),
  ### and two rows for number of observations and length of bandwidth.
  textable <- matrix("", ncol = no.col, nrow = (1+no.totcont)*2 + 2)
  resmatrix <- matrix(0, ncol = 6, nrow = no.col)
  ### The columns for the results matrix is namned
  colnames(resmatrix) <- c("Bandwidth", "Coeff", "St. error", "t-val", "p-val", "Observations")
  ### If one does not want to present estimated coefficients for controls, a row at the
  ### end of the textable will indicate whether controls have been added or not.
  if (show.controls == "no") controw <- cbind("Controls", matrix("Yes", nrow = 1, ncol = no.col))
  
  ### If at least one specification uses the IK bandwidth, the code calculates it here:
  is.ik <- (band == "ik" | band == "ik/2")
  if (mean(is.ik) > 0){
    tdyx <- na.omit(cbind(y, running))
    ik.cut <- rd_opt_bw(y = tdyx[,1], X = tdyx[,2], C_k = C_k)
  }
  
  ### The following loop goes through each specification one at a time, and saves
  ### regression results in textable and resmatrix
  for (i in 1:no.col){
    ### Saving the specification information (bandwidth and linear term)
    cut <- band[i]
    if (cut != "ik" & cut != "ik/2") cut <- as.numeric(band[i])
    if (cut == "ik") cut <- ik.cut
    if (cut == "ik/2") cut <- ik.cut/2
    pol <- poly[i]
    ### If this specification has controls, a data set with these controls, the 
    ### treatment, the running variable (and interaction), the dependent variable,
    ### and the longitud and latitud is created
    if (control[[i]][1] != "none"){
      tempcontrol <- control[[i]]
      nc <- length(tempcontrol)
      contmat <- fdata[,tempcontrol]
    }
    ### If no controls, the data set is created without controls
    if (control[[i]][1] == "none"){
      nc <- 0
    }
    ### Now, linear/quadratic or qubic is added, as well as longitud and latitud
    if (lon != "none"){
      exmat <- fdata[,c(lon,lat)]
      if (pol == 1){
        exmat <- (cbind(runtreat, running, exmat))
      }
      if (pol == 2){
        exmat <- (cbind(run2, run2treat, runtreat, running, exmat))
      }
      if (pol == 3){
        exmat <- (cbind(run3, run3treat, run2, run2treat, runtreat, running, exmat))
      }
      if (pol == 0){
        exmat <- (cbind(running, exmat))
      }      
    }
    if (lon == "none"){
      if(pol == 1){
        exmat <- cbind(runtreat, running)
      }
      if(pol == 2){
        exmat <- cbind(run2, run2treat,runtreat, running)
      }
      if(pol == 3){
        exmat <- cbind(run3, run3treat, run2, run2treat,runtreat, running)
      }
      if(pol == 0){
        exmat <- running
      }
    }
    if (nc > 0) addmat <- data.frame(contmat,exmat) else addmat <- data.frame(exmat)
    
    temp <- cbind(y, 1, treat, addmat) # This is the data set that will be removed of its NAs
    
    # If clustered standard errors are to be used for inference, the following part adds the vector(s) for the clustering:
    if (se == "cluster"){
      clust <- fdata[,cluster]
    temp <- cbind(clust, temp)  
    }

    ### All NAs are removed and observations within the bandwidth are kept
    if (lon != "none"){
      # The running variable is two positions from the last, hence we call it for the cut-off.
      tempd <- na.omit(temp[abs(temp[,dim(temp)[2]-2]) < cut,]) 
      # Since longitud and latitude are not regressors, we remove them (they have the last and the sec to last positions)
      tempd2 <- tempd[,-c((dim(temp)[2]-1):dim(temp)[2])]
    }
    if (lon == "none"){
      tempd <- na.omit(temp[abs(temp[,dim(temp)[2]]) < cut,])
      tempd2 <- tempd

    }
    if (pol == 0){
      # If a linear term is not specified, the running variable, and the product of it with the treatment are removed
      tempd2 <- tempd2[, -c((dim(tempd2)[2]-1):dim(tempd2)[2])]
    }
    if (se == "cluster"){
    # If we use clustered standard errors, the vector(s) for the clustering have been added, and are now removed:
      tempd2 <- tempd2[,-c(1:length(cluster))]
    }
    
    ### tempd2 will now have longitud and latitud removed, if they were added in the
    ### first place. These will later be used for Conley, if specified.
    
    ### The dependent variable is now saved as a separate vector, and a separate
    ### matrix for all regressors
    dv <- tempd2[,1]
    ### If a linear term is specificed, it is added to the matrix of regressors
    expl <- tempd2[,-1]

    ### The coefficients of the regression model are estimated
    reg <- lm.fit(dv, x = as.matrix(expl), tol = 2.3e-64)
    ### All estimated coefficients are saved but only the one for treatment and the
    ### controls will be used for the table
    coeffs <- reg$coefficients
    s.coeffs <- reg$coefficients[c(2:(2+nc))]
    n.obs <- length(reg$residuals) 
    df <- n.obs - dim(expl)[2]
    ### The residuals are saved to be used for estimation, and longitud and latitud are saved in case Conley is used
    res <- reg$residuals
    if (lon != "none"){
      lo <- tempd[,lon]
      la <- tempd[,lat]
    }
    ## If standard errors are clustered, the vector(s) for clustering are saved:
    if (se == "cluster"){
      cl <- tempd[1:length(cluster)]
    }
    #### No correction
    if (se == "none"){
     sdtemp <- standard(expl = expl, res = res)
    }
    if (se == "hc0"){ 
    #### hc0 correction (heteroskedasticity consistent standard errors)
     sdtemp <- hc0(expl = expl, res = res)
    }
    ### Conley standard errors
    if (se == "conley"){
     sdtemp <- conley(expl = expl, res = res, lon = lo, lat = la, 
     threshold = threshold, coord = coord)$se
    }
    ### Clustered standard errors (based on package multiwayvcov):
    if (se == "cluster"){
      library(multiwayvcov)
      library(lmtest)
      na <- names(tempd2)
      form <- paste(c("`", na[1], "`", "~", "`", na[3], "`"), collapse="")
      for (h in 4:length(na)){
        form <- paste(c(form, "+", "`", na[h], "`"), collapse="")
      }
      clreg <- lm(form, data = tempd2)
      clcov <- cluster.vcov(clreg, cl)
      sdtemp <- coeftest(clreg, clcov)[,2]
    }
    ### Saving the standard errors and computing t-values and p-values
    s.sd <- sdtemp[c(2:(2+nc))]
    tval.r <- s.coeffs/s.sd
    pval.r <- pt(abs(tval.r), df = df, lower.tail=FALSE)*2
    ### Saving the bandwidth, est. coeff. for treatment, and standard errors in the
    ### result matrix
    resmatrix[i,1] <- cut
    resmatrix[i,2] <- s.coeffs[1]
    resmatrix[i,3] <- s.sd[1]
    resmatrix[i,4] <- tval.r[1]
    resmatrix[i,5] <- pval.r[1]
    resmatrix[i,6] <- n.obs
    
    ### Saving estimated coefficients and p-values for treatment and controls (if any)
    if (infer == "p"){
      ### This uses the function "pvalround" to set p-values smaller than 
      ### round as "<0.001"
      pval <- sapply(pval.r, pvalround, round = round)
      textable[2,i] <- pval[1]
      textable[1,i] <- sprintf(spr,round(s.coeffs[1],round))
    }
    if (infer == "t"){
      tval <- sapply(tval.r, tvalround, round = round)
      textable[2,i] <- tval[1]    
      textable[1,i] <- sprintf(spr,round(s.coeffs[1],round))
    }
    if (infer == "se"){
      sd <- sapply(s.sd, pvalround, round = round)  
      textable[2,i] <- sd[1] 
      if (pval.r[1] < 0.01){
        textable[1,i] <- paste(c(sprintf(spr,round(s.coeffs[1],round)),
                         "***"), collapse="")
      }
      if (pval.r[1] < 0.05 & pval.r[1] >= 0.01){
        textable[1,i] <- paste(c(sprintf(spr,round(s.coeffs[1],round)),
                         "**"), collapse="")
      }
      if (pval.r[1] < 0.1 & pval.r[1] >= 0.05){
        textable[1,i] <- paste(c(sprintf(spr,round(s.coeffs[1],round)),
                         "*"), collapse="")
      }
      if (pval.r[1] >= 0.1){
        textable[1,i] <- sprintf(spr,round(s.coeffs[1],3))
      }
    }
    if (control[[i]][[1]] != "none"){
      for (j in 1:nc){
        po <- as.numeric(subset(controlpos, controlpos[,1] == tempcontrol[j])[2])
        ### Based on the choice of how to present inference, SE, 
        ### p-values or t-values are presented
        if (infer == "p"){ 
          textable[4+2*(po-1),i] <- pval[1+j]
          textable[3+2*(po-1),i] <- sprintf(spr,round(s.coeffs[1+j],round))
        }
        if (infer == "t"){ 
          textable[4+2*(po-1),i] <- tval[1+j]
          textable[3+2*(po-1),i] <- sprintf(spr,round(s.coeffs[1+j],round))
        }
        if (infer == "se"){
          textable[4+2*(po-1),i] <- sd[1+j]
          if (pval.r[1+j] < 0.01){
            textable[3+2*(po-1),i] <- paste(c(sprintf(spr,round(s.coeffs[1+j],round)),
                                      "***"), collapse="")
          }
          if (pval.r[1+j] < 0.05 & pval.r[1+j] >= 0.01){
            textable[3+2*(po-1),i] <- paste(c(sprintf(spr,round(s.coeffs[1+j],round)),
                                      "**"), collapse="")
          }
          if (pval.r[1+j] < 0.1 & pval.r[1+j] >= 0.05){
            textable[3+2*(po-1),i] <- paste(c(sprintf(spr,round(s.coeffs[1+j],round)),
                                      "*"), collapse="")
          }
          if (pval.r[1+j] >= 0.1){
            textable[3+2*(po-1),i] <- sprintf(spr,round(s.coeffs[1+j],3))
          }
        }

      }
    }
    ### Saving the number of observations and the bandwidth
    textable[3+no.totcont*2,i] <- n.obs
    textable[4+no.totcont*2,i] <- paste(c(round(cut,2),"km"), collapse = " ")
    ### Indicating whether this spec. had controls or not (for when controls are not to be shown)
    if (show.controls == "no"){
      if (control[[i]][1] == "none") controw[1+i] <- "No"
    }
    rm(reg, cut, pol, addmat, exmat, temp, tempd)
  }
  ### Creating a list of the names of the control variables
  if (con != "no"){
    cnames <- colnames(fdata)[which(names(fdata)%in%totcontrol)]    
  }
  ### The first column of the table will contain row names, where the first will be
  ### "Treatment", and then the names of all the control variables (if any), and lastly
  ### bandwidth and number of observations
  col1 <- matrix("",ncol = 1, nrow = dim(textable)[1])
  col1[1] <- "Treatment"
  if (con != "no"){
    for (k in 1:no.totcont){
      col1[3+2*(k-1)] <- cnames[k]
    }
  }
  col1[2*(1+no.totcont)+1] <- "Obs."
  col1[2*(1+no.totcont)+2] <- "Bandwidth"
  xtable <- cbind(col1, textable)
  if (show.controls == "no"){
    if (no.totcont > 0){
      xtable <- xtable[-(3:(2+2*no.totcont)),]
    }
    xtable <- rbind(xtable,controw)
  }
  ress <- list(treatment = resmatrix, xtable = xtable)
  return(ress) 
}
### THE FUNCTION ENDS HERE

### Since I wasn't able to source the function directly from where it had been 
### uploaded (http://rpubs.com/iangow/rd_opt_bw), I added it as a R-script on
### my computer. The code was uploaded by Ian Gow and a description of the
### function can be found at:
### http://rstudio-pubs-static.s3.amazonaws.com/529_c7406d2b4f2643b39ad80a64d2475d68.html

## Function to calculate optimal bandwidth per Imbens, Guido and Karthik
## Kalyanaraman, 'Optimal Bandwith Choice for the Regression Discontinuity
## Estimator', Review of Economic Studies, forthcoming
rd_opt_bw <- function(y, X, c = 0, C_k = 3.4375) {

    ### (1) Estimation of density (f.hat.c) and conditional variance (S.hat_c
    ### ^ 2)
    Sx <- sd(X)
    N <- length(X)
    N.pos <- sum(X >= c)
    N.neg <- sum(X < c)
    h1 <- 1.84 * Sx * (N^-0.2)

    ## Calculate the number of units on either side of the threshold, and the
    ## average outcomes on either side.
    i_plus <- (X <= c + h1) & (X >= c)
    i_minus <- (X >= c - h1) & (X < c)

    ## Estimate the density of the forcing variable at the cutpoint
    f.hat.c <- (sum(i_plus) + sum(i_minus))/(2 * N * h1)

    ## Take the average of the conditional variances of Yi given Xi = x, at x
    ## = c, from the left and the right
    sigmas <- mean(c(y[i_plus] - mean(y[i_plus]), y[i_minus] - mean(y[i_minus]))^2)

    # Step 2: Estimation of second derivatives $\hat{m}_{+}^{(2)}(c)$ and
    # $\hat{m}_{-}^{(2)}(c)$ --------- To estimate the curvature at the
    # threshold, we first need to choose bandwidths $h_{2,+}$ and $h_{2,-}$.
    # We choose these bandwidths based on an estimate of $\hat{m}^3(c)$,
    # obtained by fitting a global cubic with a jump at the threshold. We
    # estimate this global cubic regression function by dropping observations
    # with covariate values below the median of the covariate for observations
    # with covariate values below the threshold, and dropping observations
    # with covariate values above the median of the covariate for observations
    # with covariate values above the threshold.  For the observations with
    # $X_i < c$ ($X_i \geq c$), the median of the forcing variable is `r
    # median(X[X<c])` (`r median(X[X>=c])`). Next, we estimate, using the data
    # with $X_i \in$ `r median(X[X<c])` (`r median(X[X>=c])`), the polynomial
    # regression function of order three, with a jump at the threshold of c:
    step_2_data <- as.data.frame(cbind(y, X, X_d = X - c))
    step_2_lm <- lm(y ~ X_d + I(X_d^2) + I(X_d^3) + (X >= c), data = step_2_data, 
        subset = X >= median(X[X < c]) & X <= median(X[X >= c]))
    m3hat.c <- 6 * coef(step_2_lm)[4]

    h2.pos <- ((sigmas/(f.hat.c * m3hat.c^2))^(1/7) * 3.56 * (N.pos^(-1/7)))
    h2.neg <- ((sigmas/(f.hat.c * m3hat.c^2))^(1/7) * 3.56 * (N.neg^(-1/7)))

    ## Given the pilot bandwidths h2.pos and h2.neg, we estimate the curvature
    ## m(2)(c) by a local quadratic
    lm.h2.pos <- lm(y ~ X + I(X^2), data = step_2_data, subset = X >= c & X <= 
        h2.pos + c)
    m2hat.pos.c <- 2 * coef(lm.h2.pos)[3]
    N2.pos <- length(lm.h2.pos$residuals)

    lm.h2.neg <- lm(y ~ X + I(X^2), data = step_2_data, subset = X >= c - h2.neg & 
        X < c)
    m2hat.neg.c <- 2 * coef(lm.h2.neg)[3]
    N2.neg <- length(lm.h2.neg$residuals)

    ### (3) Calculation of regulation terms and optimal h.
    r.hat.pos <- (720 * sigmas)/(N2.pos * h2.pos^4)
    r.hat.neg <- (720 * sigmas)/(N2.neg * h2.neg^4)

    ### (3) Calculation of regulation terms and optimal h.

    h.opt <- C_k * ((2 * sigmas/(f.hat.c * ((m2hat.pos.c - m2hat.neg.c)^2 + 
        r.hat.pos + r.hat.neg)))^(1/5)) * (N^(-1/5))
    return(as.double(h.opt))
}