# This function is written by Sirus Dehdari (sirus.dehdari@ne.su.se), PhD candidate
# in Economics at the Institute for International Economic Studies (Stockholm).
# Latest version: 3/12/2016

### This creates a Stata outreg styled matrix for OLS estimation. The matrix can then be
### be used with xtable to create output for TeX. Basically, you get a table with all
### different specifications for the control you add, and for some dependent variables. 
### It is required that one predefines and names the variables before using them in 
### the function: interactions have to be created manually but the function will create 
### dummy variables for category variables, as long as the variable has been defined as 
### a category variable. The estimated coefficients are then presented together with 
### standard errors (and stars), t-values, or p-values.

### This function allows for standard error correction using White's robust standard
### errors (hc0) or Conley standard errors. I will add an option for two-way clustering.
### Makes sure to also load my functions for standard errors, as it is used for all 
### different corrections (and even for no correction).

### Arguments
### - fdata: your data set
### - dep: name(s) of the dependent variable. If dependent variable is the same for all
###   specifications, just repeat the same name for as many times as the
###   number of different specifications (columns in the table).
### - indep: A list of the control variable(s) for each specification. Default is set 
###   at no controls ("no"). To let some of the specifications have no controls, write
###   "none". A blank space ("") will be added to the cells in the table for the
###   controls that are excluded from some specifications. Notice that the variables' 
###   position on the list is determined by their order of appearance.
### - se: standard error correction ("hc0/"conley"/"none"). Default is set at "none"
###   which gives you standard errors under homoskedasticity. For now, all specifications
###   will have the same correction. Notice that lon, lat, coord, and threshold also 
###   need to be specified for "conley". 
### - infer: determines how to display inferens as standard errors and stars on 
###   coefficients ("se"), t-values ("t"), or p-values ("p"). Default is "se".
### - round: determines decimals for rounding. Default is 3.
### - lon/lat: for Conley standard error, coordinates are needed, either in kilometer.
###   or in degrees. If you're not using Conley standard errors, do not specify anything.
### - coord: coordinates of lon/lat, either in "km" (kilometers), or decimal degrees (dd).
###   Default is "km".
### - threshold: the threshold for Conley standard errors. Default is set at 5.

##### THE FUNCTION BEGINS HERE
regtable <- function(fdata, dep, indep, se = "none", infer = "se", round = 3, lon = "none", lat = "none", threshold = 5, coord = "km"){
  ### Saving number of specifications, and variables for longitud and latitud (if added)
  no.col <- length(dep)
  if (lon != "none"){
    long <- fdata[,lon]
    lati <- fdata[,lat]
  }
  ### Saving an expression for the rounding (based on "round")
  rr <- as.character(round)
  spr <- paste(c("%.",rr,"f"), collapse="")
  ### Since we might have some variables that are in fact category variables, we create
  ### a dummy for each and thus, each dummy will get its own row in the table. First, 
  ### we need to find out which regressors are category variables and if they are, how
  ### many categories do they need in the table (minus base category)
  totindep <- unique(unlist(indep))
  totindep <- totindep[totindep != "none"]
  totregvar <- totindep
  isfact <- rep(0, length(totindep))
  for (i in 1:length(totindep)){
    tdfact <- is.factor(fdata[,totindep[i]])
    if (tdfact == TRUE){
      isfact[i] <- length(names(table(fdata[,totindep[i]])))-1
    }
  }
  isfact[isfact == 0] <- 1
  if (sum(isfact) >= length(totindep)){
    catnames <- matrix(NA, nrow = sum(isfact), ncol = 1)
    ccs <-c(0,cumsum(isfact))
    for (j in 1:length(totindep)){
      if (is.factor(fdata[,totindep[j]]) == TRUE ){
        tempcat <- apply(cbind(totindep[j], names(table(fdata[,totindep[j]]))[-1]),1,
        function(x) paste(x,collapse=""))
        catnames[(ccs[j]+1):ccs[j+1]] <- tempcat
      }
      if (is.factor(fdata[,totindep[j]]) == FALSE){
        catnames[(ccs[j]+1):ccs[j+1]] <- totindep[j]
      }
    }
  totindep <- catnames
  }
  no.totindep <- length(totindep)
  indeppos <- data.frame(totindep,as.numeric(1:no.totindep))

  ### Creating a matrix for the results for the first regressor, and a matrix
  ### for xtable. Number of rows in textable is based on the total number of independent
  ### variables, and to this two rows are added for the treatment (estimated coefficient 
  ### and sd), and two rows for number of observations and name of dependent variable.
  textable <- matrix("", ncol = no.col, nrow = (1+no.totindep)*2 + 2)
  resmatrix <- matrix(0, ncol = 5, nrow = no.col)
  colnames(resmatrix) <- c("Coeff.", "St. error", "t-val", "p-val", "Obs.")
  
  ### The following loop goes through each specification one at a time, and saves
  ### regression results in textable and resmatrix
  for (i in 1:no.col){
    y <- fdata[, dep[i]]
    tempindep <- indep[[i]]
    ti <- which(totregvar%in%tempindep)
    indepmat <- data.frame(matrix(NA, nrow=length(y), ncol = sum(isfact[ti])))
    colnames(indepmat) <- rep("a", sum(isfact[ti]))
    xi <- 0
    for (m in 1:length(tempindep)){
      indepv <- fdata[,tempindep[m]]
      tempfact <- is.factor(indepv)
      if (tempfact == TRUE){
         imat <- dummy(indepv)
         indepmat[,(xi + 1):(xi + dim(imat)[2])] <- imat
         colnames(indepmat)[(xi + 1):(xi + dim(imat)[2])] <- apply(cbind(tempindep[m],      
         colnames(imat)), 1, function(x) paste(x,collapse=""))
         xi <- xi + dim(imat)[2]
         rm(imat)
      }
      if (tempfact == FALSE){
        indepmat[,(xi + 1):(xi + 1)] <- indepv
        colnames(indepmat)[(xi + 1):(xi + 1)] <- tempindep[m]
        xi <- xi + 1
      }
    }
    rm(indepv)
    nc <- dim(indepmat)[2]
    if (lon != "none"){
      temp <- na.omit(data.frame(y, 1, indepmat, long, lati))
    }
    if (lon == "none"){
      temp <- na.omit(data.frame(y, 1, indepmat))
    }
    dv <- temp[,1]
    expl <- temp[,2:(2+nc)]
    reg <- lm.fit(dv, x = as.matrix(expl))
    coeffs <- reg$coefficients
    n.obs <- length(reg$residuals) 
    df <- n.obs - dim(expl)[2]
    res <- reg$residuals
    if (lon != "none"){
      lo <- temp[,dim(temp)[2]-1]
      la <- temp[,dim(temp)[2]]    
    }
    if (se == "none"){
      sdtemp <- standard(expl = expl, res = res)
    }
    if (se == "hc0"){ 
      sdtemp <- hc0(expl = expl, res = res)
    }
    if (se == "conley"){
      sdtemp <- conley(expl = expl, res = res, lon = lo, lat = la, 
                threshold = threshold, coord = coord)$se
    }
    tval.r <- coeffs/sdtemp
    pval.r <- pt(abs(tval.r), df = df, lower.tail=FALSE)*2
      
    resmatrix[i,1] <- coeffs[2]
    resmatrix[i,2] <- sdtemp[2]
    resmatrix[i,3] <- tval.r[2]
    resmatrix[i,4] <- pval.r[2]
    resmatrix[i,5] <- n.obs
    
    if (infer == "p"){
      pval <- sapply(pval.r, pvalround, round = round)  
      textable[2,i] <- pval[1]
      textable[1,i] <- sprintf(spr,round(coeffs[1],round))
    } 
    if (infer == "t"){
      tval <- sapply(tval.r, tvalround, round = round)  
      textable[2,i] <- tval[1]
      textable[1,i] <- sprintf(spr,round(coeffs[1],round))
    }
    if (infer == "se"){
      sd <- sapply(sdtemp, pvalround, round = round)  
      textable[2,i] <- sd[1]
      if (pval.r[1] < 0.01){
        textable[1,i] <- paste(c(sprintf(spr,round(coeffs[1],round)),
                                  "***"), collapse="")
      }
      if (pval.r[1] < 0.05 & pval.r[1] >= 0.01){
        textable[1,i] <- paste(c(sprintf(spr,round(coeffs[1],round)),
                               "**"), collapse="")
      }
      if (pval.r[1] < 0.1 & pval.r[1] >= 0.05){
        textable[1,i] <- paste(c(sprintf(spr,round(coeffs[1],round)),
                                  "*"), collapse="")
      }
      if (pval.r[1] >= 0.1){
        textable[1,i] <- sprintf(spr,round(coeffs[1],3))
      }
    }
    
    for (j in 1:nc){
      po <- as.numeric(subset(indeppos, indeppos[,1] == colnames(indepmat)[j])[2])
      ### Presenting p-val, t-val, or standard errors (with stars on coefficients)
      if (infer == "p"){
        textable[4+2*(po-1),i] <- pval[1+j]
        textable[3+2*(po-1),i] <- sprintf(spr,round(coeffs[1+j],round))
      }
      if (infer == "t"){ 
        textable[4+2*(po-1),i] <- tval[1+j]
        textable[3+2*(po-1),i] <- sprintf(spr,round(coeffs[1+j],round))
      }
      if (infer == "se"){
        textable[4+2*(po-1),i] <- sd[1+j]
        if (pval.r[1+j] < 0.001){
          textable[3+2*(po-1),i] <- paste(c(sprintf(spr,round(coeffs[1+j],round)),
                                    "***"), collapse="")
        }
        if (pval.r[1+j] < 0.05 & pval.r[1+j] >= 0.001){
          textable[3+2*(po-1),i] <- paste(c(sprintf(spr,round(coeffs[1+j],round)),
                                    "**"), collapse="")
        }
        if (pval.r[1+j] < 0.1 & pval.r[1+j] >= 0.05){
          textable[3+2*(po-1),i] <- paste(c(sprintf(spr,round(coeffs[1+j],round)),
                                    "*"), collapse="")
        }
        if (pval.r[1+j] >= 0.1){
          textable[3+2*(po-1),i] <- sprintf(spr,round(coeffs[1+j],3))
        }
      }

    }
    textable[3+no.totindep*2,i] <- n.obs
    textable[4+no.totindep*2,i] <- dep[i]
    rm(reg,po)
  }

  col1 <- matrix("",ncol = 1, nrow = dim(textable)[1])
  col1[1] <- "Intercept"
  for (k in 1:no.totindep){
      col1[3+2*(k-1)] <- totindep[k]
  }

  col1[2*(1+no.totindep)+1] <- "Obs."
  col1[2*(1+no.totindep)+2] <- "Dep. Var."

  xtable <- cbind(col1, textable)
  ress <- list(treatment = resmatrix, xtable = xtable)
  return(ress) 
}

### This function creates a set of dummy variables for category variables.
dummy <- function(x){
  fnames <- names(table(x))
  nf <- length(fnames)
  fmat <- matrix(0, nrow = length(x), ncol = nf-1)
  colnames(fmat) <- fnames[-1]
  for (i in 1:length(x)){
    tempf <- as.character(x[i])
    if (is.na(tempf) == FALSE){
      if (tempf != fnames[1]){
        fmat[i, tempf] <- 1
      }
    }
    if (is.na(tempf) == TRUE){
      fmat[i,] <- NA
    }
  }
  return(fmat)
}


