##### "The origins of common identity: Evidence from Alsace-Lorraine"
## Authors: Sirus H. Dehdari & Kai Gehring

## AEA Project ID: openicpsr-120243

# Loading and installing packages
library(lmtest)
library(sandwich)
library(xtable)
library(miscTools) # for instertRow command
library(readstata13) # To read Stata13 dta-files
library(ggplot2)

# Loading home-made functions
source("..\\Rfunctions\\se_comp.R")
source("..\\Rfunctions\\rdd.R")
source("..\\Rfunctions\\rddplot.R")
source("..\\Rfunctions\\rddbandplot.R")
source("..\\Rfunctions\\regtable.R")

# Loading data created in other scripts:
load("..\\Rdata\\maindataFRA.RData")
load("..\\Rdata\\labels.Rdata")
load("..\\Rdata\\subsetdata.RData")

# Import cahier data
cahier_data <- read.dta13("..\\Stata_data\\processed data\\cahiers.dta", convert.factors = FALSE)

# Import data on pairwise comparisons
pairwise_data_b <- read.dta13("..\\Stata_data\\processed data\\border_pair_distance_final_merged.dta", convert.factors = FALSE)

# Import ISSP survey data aggregated on departement level (together with 92 and 05 shares)
natidentity2003_dep <- read.dta13("..\\Stata_data\\processed data\\natidentity2003_dep.dta", convert.factors = FALSE)

# Import the OIP data
oip99_01 <- read.dta13("..\\Stata_data\\processed data\\oip99_01.dta")
oip03 <- read.dta13("..\\Stata_data\\processed data\\oip2003.dta")
# Ignore warnings: they refer to Stata labels, not needed

# Saving output path:
outpath <- "..\\Paper\\tables\\"
outpath_fig <- "..\\Paper\\figures\\"

# Function that creates a matrix of RDD results:
rdd_to_xtab <- function(dmat){
  ncols <- dim(dmat$treatment)[1]
  row1 <- printround(dmat$treatment[,2])
  row2 <- paste("(",printround(dmat$treatment[,3]),")",sep = "")
  row3 <- paste("[",sapply(dmat$treatment[,5], printround, lessthanzero = TRUE),"]", sep ="")
  row4 <- dmat$treatment[,6]
  row5 <- paste(c(round(dmat$treatment[1:(ncols-1),1]),printround(dmat$treatment[ncols,1],2)), "km", sep = " ")
  fcol <- c("Treatment", "", "", "Observations", "Bandwidth")
  resmat <- cbind(fcol, rbind(row1,row2,row3,row4,row5))
  return(resmat)
}

### Parameters and controls:
# Setting threshold value for Conley standard errors:
cth <- 10

# list of explanatory variables for OLS
indeplist <- list(c("is_aslr"),c("is_aslr","dist_ger", "dist_c_METZ", 
                                 "dist_c_STRASBOURG", "dist_c_NANCY",
                                 "lorr_seg_north", "lorr_seg_middle"))

# The bandwidths to be used for RD
bands10.20 = c(10, 15, 20, "ik")
leb = length(bands10.20)

# Degree for the polynomial
poly <- rep(1,leb)
poly_10.ik <- rep(1,2)
poly2_10.ik <- rep(2,2)

# Alternative bandwidth for some tables, (10 and IK)
bands10.ik = c(10, "ik")
leb_10.ik = length(bands10.ik)
con10.ik <- rep(list(c("dist_ger", "dist_c_METZ", "dist_c_STRASBOURG", 
                       "dist_c_NANCY","lorr_seg_north", "lorr_seg_middle")), leb_10.ik)


# Control variables in RD
con10.20 <- rep(list(c("dist_ger", "dist_c_METZ", "dist_c_STRASBOURG", 
                       "dist_c_NANCY", "lorr_seg_north", "lorr_seg_middle")), leb)
# Adding controls for longitude, latitude, and their interaction (10 km)
con10_ll <- rep(list(c("dist_ger", "dist_c_METZ", "dist_c_STRASBOURG", 
                       "dist_c_NANCY","lorr_seg_north", "lorr_seg_middle",
                       "lon", "lat","lonlat")), leb_10.ik)
con10_mig <- rep(list(c("dist_ger", "dist_c_METZ", "dist_c_STRASBOURG", 
                        "dist_c_NANCY","lorr_seg_north", "lorr_seg_middle",
                        "Popdiff_16_26", "Popdiff_26_36", "Popdiff_36_46", 
                        "Popdiff_16_46")), leb_10.ik)
con10_lang <- rep(list(c("dist_ger", "dist_c_METZ", "dist_c_STRASBOURG", 
                         "dist_c_NANCY","lorr_seg_north", "lorr_seg_middle",
                         "dist_b_LANGUAGE")), leb_10.ik)

# Saving the number of controls (main spec)
no.cont <- length(con10.20[[1]])


# Remove all objects in the current workspace: rm(list = ls())

# The analysis uses the within-Lorraine data set
base_data <- compdata1


#####################################################################################################
#####################################################################################################


### Tables ----

### Cahier data
cahier_names <- c("Lorraine (average)", "Moselle (treated)", "Meurthe-et-Moselle", "Meuse")
cahier_lorraine <- na.omit(cahier_data[cahier_data$code == 55 | cahier_data$code == 54 | 
                                         cahier_data$code == 57,"NatIden"])
cahier_moselle <- na.omit(cahier_data[cahier_data$code == 57,"NatIden"])
cahier_meurte <- na.omit(cahier_data[cahier_data$code == 54,"NatIden"])
cahier_meuse <- na.omit(cahier_data[cahier_data$code == 55,"NatIden"])


row_lorraine <- c(printround(c(mean(cahier_lorraine), sd(cahier_lorraine)),1),
                  length(cahier_lorraine))
row_moselle <- c(printround(c(mean(cahier_moselle), sd(cahier_moselle)),1),
                 length(cahier_moselle))
row_meurte <- c(printround(c(mean(cahier_meurte), sd(cahier_meurte)),1),
                length(cahier_meurte))
row_meuse <- c(printround(c(mean(cahier_meuse), sd(cahier_meuse)),1),
               length(cahier_meuse))

cahier_tab <- cbind(cahier_names,rbind(row_lorraine,row_moselle,row_meurte,row_meuse))

# XTABLE for Cahier results
print(xtable(cahier_tab),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "cahier_tab1.tex", sep = ""))





### OLS ----

# OLS estimates for 1969 referendum, within Lorraine
depvar <- "yes69"
lmfunc1 <- paste(depvar, paste(indeplist[[2]], collapse = "+"), sep = "~")
tempreg <- lm(lmfunc1, data = base_data)
resi <- tempreg$residuals
expl <- cbind(1,base_data[complete.cases(base_data[,c(depvar,indeplist[[2]])]),indeplist[[2]]])
lonlat <- base_data[complete.cases(base_data[,c(depvar,indeplist[[2]])]),c("lon","lat")]
conley_sd <- conley(expl, res = resi, lon = lonlat[,1], lat = lonlat[,2], threshold = 5, coord = "km")$se[2]
# We compute the p-value from the t-test:
pval <- 2*pt(abs(tempreg$coefficients[2]/conley_sd),tempreg$df.residual, lower.tail = FALSE)

ref69 <- c(printround(tempreg$coefficients[2]), paste("(",printround(conley_sd),")",sep = ""),
           paste("[",printround(pval, lessthanzero = TRUE),"]",sep = ""),printround(summary(tempreg)$adj.r.squared,3),nobs(tempreg))


### OLS for survey data on religion, and share of yes votes 92 and 05 (departmenet level)
indcont <- c("sex", "age", "educyrs",   "degree",  "urbrural",  "union", "rincome", "hompop")
indeplist <- list(c(indcont,"attend"),c(paste("D_attend",as.numeric(1:5), sep = ""), indcont),
                  c(paste("Relig",as.numeric(2:7), sep = ""), indcont))

relig_92 <- regtable(fdata = natidentity2003_dep, dep = rep("r92_yf",3), indep = indeplist, 
                     se = "hc0", infer = "p", round = 3)
relig_05 <- regtable(fdata = natidentity2003_dep, dep = rep("r05_yf",3), indep = indeplist, 
                     se = "hc0", infer = "p", round = 3)

cnames <- c("Attendance (mean)", "", "Attendance: Weekly", "", "Attendance: 2-3 times a month", 
            "", "Attendance: Once a month", "", "Attendance: Sev. times a year", "", "Attendance: Less freq.", "", "Roman Catholic", "",
            "Protestant", "", "Christian Ortodox", "", "Jewish", "", "Moslem", "", "Other Religions", "", "Obs.")

relig_92$xtable <- cbind(cnames,relig_92$xtable[-c(1:18,dim(relig_92$xtable)[1]),-1])
relig_05$xtable <- cbind(relig_05$xtable[-c(1:18,dim(relig_05$xtable)[1]),-1])

relig_92$xtable <- gsub("\\)","]",gsub("\\(","[",relig_92$xtable))
relig_05$xtable <- gsub("\\)","]",gsub("\\(","[",relig_05$xtable))



### XTABLE
print(xtable(cbind(relig_92$xtable,relig_05$xtable)),floating = FALSE, only.contents=TRUE, 
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex",
      file = paste(outpath, "relig_yes.tex", sep = ""))




### RDD Estimates ----

# RD for 1969 referendum, within Lorraine
ref69_wL <- rddxtab(dep = "yes69", fdata = base_data, band = bands10.20, poly = poly, 
                    se = "conley", control = con10.20, lon = "lon", lat = "lat", 
                    run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                    show.controls = "no")

# RD 1969, excluding German-speaking communes
rob69_wL_fr <- rddxtab(dep = "yes69", fdata = compdata1.fr, band = bands10.ik, 
                       poly = poly_10.ik, se = "conley", control = con10.ik, 
                       lon = "lon", lat = "lat", run = "dist_aslr", infer = "se", 
                       threshold = cth, coord = "km",show.controls = "no")

# RD 1969, controlling for longitude, latitude, and their interaction
rob69_ll <- rddxtab(dep = "yes69", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                    se = "conley", control = con10_ll, lon = "lon", lat = "lat", 
                    run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                    show.controls = "no")

# ## Saving to tex table:

# XTABLE for OLS and RD results
print(xtable(cbind(rdd_to_xtab(ref69_wL)[,1], c(ref69[-4],"-"),
                   rdd_to_xtab(ref69_wL)[,c(2,5)],
                   rdd_to_xtab(rob69_wL_fr)[,3],rdd_to_xtab(rob69_ll)[,3])),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "rddols69_wL.tex", sep = ""))


### RD estimates for 1992, 2005, newspaper, and regionalist parties
ref92_wL <- rddxtab(dep = "yes92", fdata = base_data, band = bands10.20, poly = poly, se = "conley", control = con10.20, 
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
ref05_wL <- rddxtab(dep = "yes05", fdata = base_data, band = bands10.20, poly = poly, se = "conley", control = con10.20, 
                    lon = "lon", lat = "lat", run = "dist_aslr", infer = "se", threshold = cth, coord = "km",show.controls = "no")

regP_wL <- rddxtab(dep = "reg15VoixExpLREG", fdata = base_data,
                   band = bands10.20, poly = poly, se = "conley", control = con10.20, 
                   lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, 
                   coord = "km", show.controls = "no")
abo_wL <- rddxtab(dep = "avgABO_ph", fdata = base_data, bands10.20, poly = poly, se = "conley", control = con10.20, 
                  lon = "lon", lat = "lat", run = "dist_aslr", infer = "se", threshold = cth, coord = "km",show.controls = "no")


# in-text numbers (page 16: share of votes for regionalist parties in treated vs 
# non-treated area):

# Treated:
mean(base_data$reg15VoixExpLREG[base_data$is_aslr == 1], na.rm = TRUE)

# Untreated:
mean(base_data$reg15VoixExpLREG[base_data$is_aslr == 0], na.rm = TRUE)

# Percentage increase compared to untreated mean:
100*(regP_wL$treatment[4,2]/mean(base_data$reg15VoixExpLREG[base_data$is_aslr == 0], na.rm = TRUE))


# XTABLE, Short 1992, 2005, newspaper, regionalist (only Optimal Bandwidth):
print(xtable(cbind(rdd_to_xtab(ref92_wL)[,c(1,5)],rdd_to_xtab(ref05_wL)[,5], 
                   rdd_to_xtab(abo_wL)[,5],rdd_to_xtab(regP_wL)[,5])),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "rdd_extra_wL.tex", sep = ""))


### RD at language border
con10.20_lang <- rep(list(c("dist_ger", "dist_c_METZ", "dist_c_STRASBOURG", "dist_c_NANCY", 
                            "lorr_seg_north", "lorr_seg_middle")), leb)

lang69 <- rddxtab(dep = "yes69", fdata = annexdata, band = bands10.20, poly = poly,
                  se = "conley", control = con10.20_lang, lon = "lon", lat = "lat", 
                  run = "dist_b_LANGUAGE", threshold = cth, coord = "km",
                  show.controls = "no")


# Xtable
print(xtable(rdd_to_xtab(lang69)[,c(1,2,5)]),floating = FALSE,
      only.contents=TRUE, include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "lang_69.tex", sep = ""))


### Placebo RD
## Placebo border, within modern Moselle
moselle69 <- rddxtab(dep = "yes69", fdata = base_data, band = bands10.20, poly = poly, se = "conley", control = con10.20, 
                     lon = "lon", lat = "lat", run = "dist_old_border", threshold = cth, coord = "km", show.controls = "no")

# Save to tex table
print(xtable(cbind(rdd_to_xtab(moselle69))),floating = FALSE,
      only.contents=TRUE, include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "moselle69.tex", sep = ""))



### Pre-treatment variables, within Lorraine
placeborugged <- rddxtab(dep = "rugged", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                         lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
placeboelev <- rddxtab(dep = "ra_elevation_raster", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                       lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
placebowheat <- rddxtab(dep = "wheat_int_rf", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
placebopotato <- rddxtab(dep = "potato_int_rf", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                         lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placebobarley <- rddxtab(dep = "barley_int_irr", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                         lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placeboelevstd <- rddxtab(dep = "elevation_std", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                          lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")


placebop1866 <- rddxtab(dep = "p1866", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placeboproad <- rddxtab(dep = "road_length", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placebopgrazing <- rddxtab(dep = "LU_grazing_1860", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                           lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placebopcropland <- rddxtab(dep = "LU_cropland_1860", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                            lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")

placebopRR_stations <- rddxtab(dep = "gare_1860", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                               lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")

placebopRR_quality <- rddxtab(dep = "hie_1860", fdata = base_data, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                              lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")


# Save to tex table
print(xtable(cbind(rdd_to_xtab(placebowheat),
                   rdd_to_xtab(placebopotato)[,-1], rdd_to_xtab(placebobarley)[,-1])),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "RD_pretreatment1.tex", sep = ""))

print(xtable(cbind(rdd_to_xtab(placeboelev),
                   rdd_to_xtab(placeboelevstd)[,-1], rdd_to_xtab(placeborugged)[,-1])),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "RD_pretreatment2.tex", sep = ""))

print(xtable(cbind(rdd_to_xtab(placebopcropland),
                   rdd_to_xtab(placebopgrazing)[,-1], rdd_to_xtab(placebop1866)[,-1])),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "RD_pretreatment3.tex", sep = ""))

print(xtable(cbind(rdd_to_xtab(placeboproad),
                   rdd_to_xtab(placebopRR_stations)[,-1], rdd_to_xtab(placebopRR_quality)[,-1])),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "RD_pretreatment4.tex", sep = ""))


### Turnout in 1969, 1992, and 2005 (Table for Appendix)
varnames <- c("Turnout 1969", "Turnout 1992", "Turnout 2005")
ref69_turnout <- rddxtab(dep = "r69_turnout", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                         run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")
ref92_turnout <- rddxtab(dep = "r92_turnout", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                         run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")
ref05_turnout <- rddxtab(dep = "r05_turnout", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                         run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")

# Save to tex table
print(xtable(cbind(rdd_to_xtab(ref69_turnout)[,1], rdd_to_xtab(ref69_turnout)[,3],
                   rdd_to_xtab(ref92_turnout)[,3], rdd_to_xtab(ref05_turnout)[,3])),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "turnout_rdd.tex", sep = ""))


### All of Alsace and Lorraine

ref92_AL <- rddxtab(dep = "yes92", fdata = aldata, band = bands10.ik, poly = poly_10.ik, 
                    se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                    run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                    show.controls = "no")
ref05_AL <- rddxtab(dep = "yes05", fdata = aldata, band = bands10.ik, poly = poly_10.ik, 
                    se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                    run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                    show.controls = "no")
regP_AL <- rddxtab(dep = "reg15VoixExpLREG", fdata = aldata, band = bands10.ik, poly = poly_10.ik, 
                   se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                   run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                   show.controls = "no")

# Save to tex table
print(xtable(cbind(rdd_to_xtab(ref92_AL)[,1], rdd_to_xtab(ref92_AL)[,3],
                   rdd_to_xtab(ref05_AL)[,3], rdd_to_xtab(regP_AL)[,3])),
      floating = FALSE, only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "rdd_AL.tex", sep = ""))


### Covariates

# Religio-cultural variables:
out_wedlock <- rddxtab(dep = "out_wedlock99", fdata = base_data, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                       lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
single_parents <- rddxtab(dep = "single_parents99", fdata = base_data, band =  bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                          lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
churches_numb <- rddxtab(dep = "churches_number", fdata = base_data, band =  bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                         lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
catholicchurch <- rddxtab(dep = "catholic_dummy", fdata = base_data, band =  bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                          lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

# Socio-economic and demographic variables
income <- rddxtab(dep = "medinc08", fdata = base_data, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                  lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
mean_age <- rddxtab(dep = "mean_age06", fdata = base_data, band =  bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
education <- rddxtab(dep = "school99.bac", fdata = base_data, band =  bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                     lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
occupation <- rddxtab(dep = "share_workers06", fdata = base_data, band =  bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                      lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")


# Sports, healthcare, elementary and high schools, athletic centers

# First, create some summed variables
base_data$schools <- base_data$elschools + base_data$highschools
base_data$health <- base_data$psych + base_data$healthcare_short + 
  base_data$healthcare_medium + base_data$healthcare_long +
  base_data$serv_house
base_data$voca <- base_data$voc_schools + base_data$tech_voc

post_health <- rddxtab(dep = "health", fdata = base_data, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                       lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
post_schools <- rddxtab(dep = "schools", fdata = base_data, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
athletic <- rddxtab(dep = "athletic", fdata = base_data, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
post_office <- rddxtab(dep = "post", fdata = base_data, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik, 
                       lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")


# Only IK bandwidth for cultural goods
print(xtable(cbind(rdd_to_xtab(out_wedlock)[,c(1,3)], rdd_to_xtab(single_parents)[,3], 
                   rdd_to_xtab(churches_numb)[,3], rdd_to_xtab(catholicchurch)[,3])),
      floating = FALSE,only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "cultural.tex", sep = ""))

# Only IK bandwidth for median income, mean age, education, occupation
print(xtable(cbind(rdd_to_xtab(income)[,c(1,3)], rdd_to_xtab(mean_age)[,3], 
                   rdd_to_xtab(education)[,3], rdd_to_xtab(occupation)[,3])),
      floating = FALSE,only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "socioecon.tex", sep = ""))

# Only IK bandwidth for public goods
print(xtable(cbind(rdd_to_xtab(post_health)[,c(1,3)], rdd_to_xtab(post_office)[,3], 
                   rdd_to_xtab(post_schools)[,3], rdd_to_xtab(athletic)[,3])),
      floating = FALSE,only.contents=TRUE, include.rownames = FALSE,
      include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "public_goods.tex", sep = ""))


### Twitter data
twitter_lorraine_ger <- rddxtab(dep = "Germany_tweet_share", fdata = compdata1, band = bands10.ik, poly = poly_10.ik, se = "conley", 
                                control = con10.ik, lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", 
                                show.controls = "no")

twitter_lorraine_fra <- rddxtab(dep = "France_tweet_share", fdata = compdata1, band = bands10.ik, poly = poly_10.ik, se = "conley", 
                                control = con10.ik, lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", 
                                show.controls = "no")

# XTABLE
print(xtable(cbind(rdd_to_xtab(twitter_lorraine_ger), rdd_to_xtab(twitter_lorraine_fra)[,-1])),floating = FALSE,
      only.contents=TRUE, include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "twitter_lorraine.tex", sep = ""))



### RD Plots ----
# Setting width and height for plots (save to pdf)
wid = 5
hei = 3

# Outcomes:
# RD plot for 1969 referendum
rdplot_yes69_20km <- rddplot(fdata = base_data, dep = "yes69", 
                             run = "dist_aslr", band = 20, bin = 4, poly = 1, 
                             pshape = 4, psize= 0.5, lsize = 1, lcol = "red", 
                             msize = 2, mshape = 19)
# RD plot for 1992 and 2005 referenda
rdplot_yes92_20km <- rddplot(fdata = base_data, dep = "yes92", 
                             run = "dist_aslr", band = 20, bin = 4, poly = 1, 
                             pshape = 4, psize= 0.5, lsize = 1, lcol = "red", 
                             msize = 2, mshape = 19)
rdplot_yes05_20km <- rddplot(fdata = base_data, dep = "yes05", 
                             run = "dist_aslr", band = 20, bin = 4, poly = 1, 
                             pshape = 4, psize= 0.5, lsize = 1, lcol = "red",
                             msize = 2, mshape = 19)
# RD plot for newspaper subscription
rdplot_newspaper_20km <- rddplot(fdata = base_data, dep = "avgABO_ph", 
                                 run = "dist_aslr", band = 20, bin = 4, poly = 1, 
                                 pshape = 4, psize= 0.5, lsize = 1, lcol = "red",
                                 msize = 2, mshape = 19)
# RD plot for regionalist parties
rdplot_regP_20km <- rddplot(fdata = base_data, dep = "reg15VoixExpLREG", 
                            run = "dist_aslr", band = 20, bin = 4, poly = 1, 
                            pshape = 4, psize= 0.5, lsize = 1, lcol = "red",
                            msize = 2, mshape = 19)


bw_size <- 20
# Saving RD plots as pdf
pdf(paste(outpath_fig, "rdplot_yes69c1_20km.pdf", sep = ""), width = wid-2, height = hei-1)
rdplot_yes69_20km + theme_bw(base_size = bw_size-8) +  xlab("km") + ylab("Share Yes 1969") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(30, 90)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()

pdf(paste(outpath_fig, "rdplot_yes92c1_20km.pdf", sep = ""), width = wid-2, height = hei-1)
rdplot_yes92_20km + theme_bw(base_size = bw_size-9)+ xlab("km") + ylab("Share Yes 1992") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(40, 60)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()

pdf(paste(outpath_fig, "rdplot_yes05c1_20km.pdf", sep = ""), width = wid-2, height = hei-1)
rdplot_yes05_20km + theme_bw(base_size = bw_size-9) + xlab("km") + ylab("Share Yes 2005") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(30, 60)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()

pdf(paste(outpath_fig, "rdplot_newspaper_20km.pdf", sep = ""), width = wid-2, height = hei-1)
rdplot_newspaper_20km + theme_bw(base_size = bw_size-9) + xlab("km") + ylab("Newspaper subscription") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(0, 25)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()

pdf(paste(outpath_fig, "rdplot_regP_20km.pdf", sep = ""), width = wid-2, height = hei-1)
rdplot_regP_20km + theme_bw(base_size = bw_size-9) + xlab("km") + ylab("Regionalist parties") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(0.5, 3)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()


# Pre-treatment variables:
band_w <- 10
bins_n <- 2
# within Lorraine, pre-treatment:
rdplot_rugged <- rddplot(fdata = compdata1, dep = "rugged", run = "dist_aslr", band = band_w, 
                         bin = bins_n, poly = 1, pshape = 4, psize= 0.5, lsize = 1, 
                         lcol = "red", msize = 2, mshape = 19)
rdplot_elevation <- rddplot(fdata = compdata1, dep = "ra_elevation_raster", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                            pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)
rdplot_potato <- rddplot(fdata = compdata1, dep = "potato_int_rf", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                         pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)
rdplot_wheat <- rddplot(fdata = compdata1, dep = "wheat_int_rf", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                        pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)
rdplot_barley <- rddplot(fdata = compdata1, dep = "barley_int_irr", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                         pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)
rdplot_elevstd <- rddplot(fdata = compdata1, dep = "elevation_std", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                          pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)
rdplot_p1866 <- rddplot(fdata = compdata1, dep = "p1866", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                        pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)
rdplot_road <- rddplot(fdata = compdata1, dep = "road_length", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                       pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)
rdplot_RR_stations <- rddplot(fdata = compdata1, dep = "gare_1860", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                              pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)

rdplot_RR_quality <- rddplot(fdata = compdata1, dep = "rrqual", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                             pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)

rdplot_grazing <- rddplot(fdata = compdata1, dep = "LU_grazing_1860", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                          pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)

rdplot_cropland <- rddplot(fdata = compdata1, dep = "LU_cropland_1860", run = "dist_aslr", band = band_w, bin = bins_n, poly = 1, 
                           pshape = 4, psize= 0.5, lsize = 1, lcol = "red", msize = 2, mshape = 19)


# Saving RD plots for pre-treatment variables as pdf files:
wplus <- 0
hplus <- 0
bw_size <- 20

pdf(paste(outpath_fig, "rdplot_rugged.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_rugged + theme_bw(base_size = bw_size) + xlab("km") + ylab("Ruggedness") + 
  geom_vline(xintercept = 0, colour = "orange", size = 0.8) +
  coord_cartesian(ylim = c(0, 125)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_elevation.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_elevation + theme_bw(base_size = bw_size) + xlab("km") + ylab("Elevation") + 
  geom_vline(xintercept = 0, colour = "orange", size = 0.8) + 
  coord_cartesian(ylim = c(150, 375)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_potato.pdf", sep = ""),  width = wid-wplus, height = hei-hplus)
rdplot_potato + theme_bw(base_size = bw_size) + xlab("km") + ylab("Suitability, potato") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(20, 55)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_wheat.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_wheat + theme_bw(base_size = bw_size) + xlab("km") + ylab("Suitability, wheat") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(58, 65)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_barley.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_barley + theme_bw(base_size = bw_size) + xlab("km") + ylab("Suitability, barley") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(35, 80)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_elevstd.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_elevstd + theme_bw(base_size = bw_size) + xlab("km") + ylab("Std. elevation") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(0, 50)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_p1860.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_p1866 + theme_bw(base_size = bw_size) + xlab("km") + ylab("Pop. density, 1860") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(0, 15)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_road.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_road + theme_bw(base_size = bw_size) + xlab("km") + ylab("Road length, 1860") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(1, 8)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_grazing.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_grazing + theme_bw(base_size = bw_size) + xlab("km") + ylab("Grazing, 1860") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(10, 45)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_cropland.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_cropland + theme_bw(base_size = bw_size) + xlab("km") + ylab("Cropland, 1860") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(5, 35)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_RR_quality.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_RR_quality + theme_bw(base_size = bw_size) + xlab("km") + ylab("RR quality, 1860") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(0, 1)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()
pdf(paste(outpath_fig, "rdplot_RR_stations.pdf", sep = ""), width = wid-wplus, height = hei-hplus)
rdplot_RR_stations + theme_bw(base_size = bw_size) + xlab("km") + ylab("RR stations, 1860") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(0, 1)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()


### Placebo: Maginot line, for 1969
rdplot_yes69_maginot <- rddplot(fdata = base_data, dep = "yes69", 
                                run = "distance_maginot", band = 20, bin = 4, poly = 1, 
                                pshape = 4, psize= 0.5, lsize = 1, lcol = "red", 
                                msize = 2, mshape = 19)

bw_size <- 20
pdf(paste(outpath_fig, "rdplot_yes69_maginot.pdf", sep = ""), width = wid-2, height = hei-1)
rdplot_yes69_maginot + theme_bw(base_size = bw_size-8) + xlab("km") + ylab("Share Yes 1969") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(30, 90), xlim = c(-20,15)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()


### Placebo: old departement border
rdplot_yes69_olddep <- rddplot(fdata = base_data, dep = "yes69", 
                               run = "dist_old_border", band = 20, bin = 4, poly = 1, 
                               pshape = 4, psize= 0.5, lsize = 1, lcol = "red", 
                               msize = 2, mshape = 19)

bw_size <- 20
pdf(paste(outpath_fig, "rdplot_yes69_olddep.pdf", sep = ""), width = wid-2, height = hei-1)
rdplot_yes69_olddep + theme_bw(base_size = bw_size-8) + xlab("km") + ylab("Share Yes 1969") + 
  geom_vline(xintercept = 0, colour = "orange", size = 1.2) + 
  coord_cartesian(ylim = c(30, 90)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()



### Bandwidth plots ----
# 1969, 10 to 50 km

# Computing optimal IK bandwidth
tdyx <- na.omit(cbind(base_data[,"yes69"], base_data[,"dist_aslr"]))
optlorraine69 <- rd_opt_bw(tdyx[,1], tdyx[,2], C_k = 5.4)


cth <- 10
bandw <- 10:50
lband <- length(bandw)
poly <- rep(1, lband)
continc <- c("dist_ger", "dist_c_METZ", 
             "dist_c_STRASBOURG", "dist_c_NANCY",
             "lorr_seg_north", "lorr_seg_middle")
con10.50 <- rep(list(continc), lband)

bwlorraine69p1 <- rddxtab(dep = "yes69", fdata = compdata1, band = bandw, poly = poly, 
                          se = "conley", control = con10.50, 
                          lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, 
                          coord = "km")

# Setting width and height for plots (save to pdf)
wid = 5
hei = 3

# Save to PDF
pdf(paste(outpath_fig, "yes69bpc1p1.pdf", sep = ""), width = wid-0.6, height = hei-0)
rddbandplot(fdata = bwlorraine69p1$treatment, xlab = "Bandwidth, km", 
            ylab = "Coefficient estimates", ymin = -2, alpha = 0.05)
segments(x0 = optlorraine69, y0 = -2e10, y1 = 2e10, lwd  = 2, col = "red", lty = 3)
dev.off()


### Coefficient plots ----

# PLACEBO: Pre-treatment variables
# Standardize pre-treatment variables
prevars <- c("rugged", "ra_elevation_raster", "wheat_int_rf", "potato_int_rf", 
             "barley_int_irr", "elevation_std","p1866", "road_length","LU_grazing_1860", 
             "LU_cropland_1860","gare_1860", "hie_1860")

base_data_prevars <- base_data
base_data_prevars[,prevars] <- scale(base_data_prevars[,prevars])


bands10.ik = c(10,"ik")
leb_10.ik = length(bands10.ik)
con10.ik <- rep(list(c("dist_ger", "dist_c_METZ", "dist_c_STRASBOURG", "dist_c_NANCY","lorr_seg_north", "lorr_seg_middle")), leb_10.ik)
poly_10.ik <- rep(1,leb_10.ik)


# Pre-treatment variables, within Lorraine
placeborugged <- rddxtab(dep = "rugged", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                         lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
placeboelev <- rddxtab(dep = "ra_elevation_raster", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                       lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
placebowheat <- rddxtab(dep = "wheat_int_rf", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
placebopotato <- rddxtab(dep = "potato_int_rf", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                         lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placebobarley <- rddxtab(dep = "barley_int_irr", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                         lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placeboelevstd <- rddxtab(dep = "elevation_std", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                          lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")


placebop1866 <- rddxtab(dep = "p1866", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placeboproad <- rddxtab(dep = "road_length", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placebopgrazing <- rddxtab(dep = "LU_grazing_1860", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                           lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")
placebopcropland <- rddxtab(dep = "LU_cropland_1860", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                            lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")

placebopRR_stations <- rddxtab(dep = "gare_1860", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                               lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")

placebopRR_quality <- rddxtab(dep = "hie_1860", fdata = base_data_prevars, band = bands10.ik , poly = poly_10.ik, se = "conley", control = con10.ik, 
                              lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km", show.controls = "no")


coeff_tab <- data.frame(Estimate = c(placeborugged$treatment[1:2,2], placeboelev$treatment[1:2,2],
                                     placebowheat$treatment[1:2,2], placebopotato$treatment[1:2,2],
                                     placebobarley$treatment[1:2,2], placeboelevstd$treatment[1:2,2],
                                     placebop1866$treatment[1:2,2], placeboproad$treatment[1:2,2],
                                     placebopRR_stations$treatment[1:2,2], 
                                     placebopRR_quality$treatment[1:2,2],
                                     placebopgrazing$treatment[1:2,2],
                                     placebopcropland$treatment[1:2,2]),
                        Std = c(placeborugged$treatment[1:2,3], placeboelev$treatment[1:2,3],
                                placebowheat$treatment[1:2,3], placebopotato$treatment[1:2,3],
                                placebobarley$treatment[1:2,3], placeboelevstd$treatment[1:2,3],
                                placebop1866$treatment[1:2,3], placeboproad$treatment[1:2,3],
                                placebopRR_stations$treatment[1:2,3], 
                                placebopRR_quality$treatment[1:2,3],
                                placebopgrazing$treatment[1:2,3],
                                placebopcropland$treatment[1:2,3]),
                        Group = c(rep("Ruggedness",2), rep("Elevation",2), rep("Wheat",2), 
                                  rep("Potato",2), rep("Barley",2), rep("Std. Elevation",2), 
                                  rep("Population 1866",2), rep("Roads 1800",2), rep("RR stations 1860",2),
                                  rep("RR quality 1860",2),
                                  rep("Grazing 1860",2),
                                  rep("Cropland 1860",2)),
                        main = rep(c("10 km", "Optimal BW"),12))
coeff_tab$Group <- factor(coeff_tab$Group, levels = c("RR quality 1860", "RR stations 1860",
                                                      "Roads 1800", "Population 1866",
                                                      "Grazing 1860", "Cropland 1860",
                                                      "Ruggedness", "Std. Elevation",
                                                      "Elevation",  
                                                      "Barley", "Potato",  "Wheat"))
coeff_tab$main <- factor(coeff_tab$main, levels = c("Optimal BW", "10 km"))



t_stat <- 1.96
coeff_plot <- ggplot(coeff_tab, aes(y = Estimate, x = Group, fill= main))
dodge = position_dodge(width = 0.5)

pdf(paste(outpath_fig,"pre_treatment_coeff.pdf", sep = ""), paper = "a4r",width = 20,  height = 4)
coeff_plot + geom_point(colour = "red", size = 3, aes(shape = main), position = dodge) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), 
                position = dodge, width = 0.2) + ylim(-1.5,1.5) +
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Pre-treatment variables") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()


### Placebo: old departments (Moselle and Meurte-et-Moselle separately), and Maginot line
varnames <- c("Old dpartement border", "Maginot Line")

ref69_olddep <- rddxtab(dep = "yes69", fdata = base_data, band = bands10.ik, 
                        poly = poly_10.ik, se = "conley", control = con10.ik, 
                        lon = "lon", lat = "lat", run = "dist_old_border", infer = "se", 
                        threshold = cth, coord = "km", 
                        show.controls = "no")

ref69_maginot <- rddxtab(dep = "yes69", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                         run = "distance_maginot", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")


coeff_tab <- data.frame(Estimate = c(ref69_olddep$treatment[1:2,2], 
                                     ref69_maginot$treatment[1:2,2]),
                        Std = c(ref69_olddep$treatment[1:2,3], 
                                ref69_maginot$treatment[1:2,3]),
                        Group = c(rep(varnames[1],2), rep(varnames[2],2)),
                        main = rep(c("10 km", "Optimal BW"),2))
coeff_tab$Group <- factor(coeff_tab$Group, levels = rev(varnames))
coeff_tab$main <- factor(coeff_tab$main, levels = c("Optimal BW", "10 km"))

t_stat <- 1.96
coeff_plot <- ggplot(coeff_tab, aes(y = Estimate, x = Group, fill= main))
dodge = position_dodge(width = 0.5)

pdf(paste(outpath_fig,"placebo_olddep_maginot.pdf", sep = ""), paper = "a4r",width = 20,  height = 4)
coeff_plot + geom_point(colour = "red", size = 3, aes(shape = main), position = dodge) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), 
                position = dodge, width = 0.2) + 
  ylim(-20,20) +
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Pre-treatment variables") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()



### Turnout in 1969, 1992, and 2005
varnames <- c("Turnout 1969", "Turnout 1992", "Turnout 2005")
ref69_turnout <- rddxtab(dep = "r69_turnout", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                         run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")$treatment[2,2:3]
ref92_turnout <- rddxtab(dep = "r92_turnout", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                         run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")$treatment[2,2:3]
ref05_turnout <- rddxtab(dep = "r05_turnout", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                         run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")$treatment[2,2:3]

turnout_tab <- data.frame(Variable = varnames, Estimate = c(ref69_turnout[1], 
                                                            ref92_turnout[1], ref05_turnout[1]), 
                          Std = c(ref69_turnout[2], 
                                  ref92_turnout[2], ref05_turnout[2]))

turnout_tab$Variable <- factor(turnout_tab$Variable, 
                               levels = rev(varnames))

t_stat <- 1.96
turnout_plot <- ggplot(turnout_tab, aes(y = Estimate, x = Variable))

pdf(paste(outpath_fig,"turnout_plot.pdf", sep = ""), paper = "a4r",width = 20,  height = 4)
turnout_plot + geom_point(colour = "red", size = 3) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), width = 0.2) + 
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Variable") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()


### Other variables, long list
contemp_covars <- c("share_workers06", "share_farmers06", "share_artisans06",
                    "share_executives06", "share_intermediate06", "companies11",
                    "industri11", "building11", "commercial11", "public11", 
                    "theatre", "multisport", "athletic", "swimming", "healthcare_short",
                    "healthcare_medium", "healthcare_long", "dis_adults", "dis_children",
                    "psych", "post", "serv_house", "elschools", "highschools", 
                    "voc_schools", "tech_voc", "nursery_schools", "pop_area", 
                    "cr_burglary", "cr_gta", "cr_property_damage",
                    "charcuteries", "fish_shops", "florists")

base_data_covars <- base_data
base_data_covars[,contemp_covars] <- scale(base_data_covars[,contemp_covars])

varnames <- c("Share workers", "Share farmers", "Share artisans", "Share executives", 
              "Share intermediate", "Companies", "Industrial est.", 
              "Building est.", "Commercial est.", "Public est.", "Theatre rooms", 
              "Multisport fac.", "Athletic centers", "Swimming fac.", "Healthcare (short)",
              "Healthcare (medium)", "Healthcare (long)", "Accom. disabled adults", 
              "Accom. disabled children", "Psychiatric est.",
              "Post offices", "Service houses", "Elementary schools", "Highschools",
              "Vocational training", "Tech. vocational training", "Nursery schools",
              "Population density", "Burglary", "Motor vehicle theft", 
              "Property damage", "Charcuteries", "Fish shops", "Florists")


## Occupation/employment variables
workers06 <- rddxtab(dep = "share_workers06", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                     lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Share farmers
farmers06 <- rddxtab(dep = "share_farmers06", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                     lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Share artisans
artisans06 <- rddxtab(dep = "share_artisans06", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                      lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Share executives
executives06 <- rddxtab(dep = "share_executives06", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# share intermediate professions
intermediate06 <- rddxtab(dep = "share_intermediate06", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                          lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

## Industrial establishments and companies, 2011:
# Number of companies, per capita:
companies11 <- rddxtab(dep = "companies11", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                       lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of industrial establishments, per capita
industri11 <- rddxtab(dep = "industri11", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                      lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of building establishments, per capita
building11 <- rddxtab(dep = "building11", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                      lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of commercial, transport and miscellaneous services establishments, per capita
commercial11 <- rddxtab(dep = "commercial11", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of public administration, education, health and social welfare companies, per capita
public11 <- rddxtab(dep = "public11", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

## Public goods
# Number of theatres, per capita
theatre <- rddxtab(dep = "theatre", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                   lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of "multisport" facilities, per capita
multisport <- rddxtab(dep = "multisport", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                      lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of "Athletisme" facilities, per capita
athletic <- rddxtab(dep = "athletic", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of public swimming facilities, per capita
swimming <- rddxtab(dep = "swimming", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of Health care establishments for short stays, per capita
healthcare_short <- rddxtab(dep = "healthcare_short", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                            lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of Health care establishments for medium-term stays, per capita
healthcare_medium <- rddxtab(dep = "healthcare_medium", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                             lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of Health care establishments for long stays, per capita
healthcare_long <- rddxtab(dep = "healthcare_long", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                           lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Accommodation for disabled adults
dis_adults <- rddxtab(dep = "dis_adults", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                      lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Accommodation for disabled children
dis_children <- rddxtab(dep = "dis_children", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of psychiatric establishments, per capita
psych <- rddxtab(dep = "psych", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                 lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of post offices, per capita
post <- rddxtab(dep = "post", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
serv_house <- rddxtab(dep = "serv_house", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                      lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

## Training
# Number of elementary schools, per capita
elschools <- rddxtab(dep = "elschools", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                     lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of high-schools with general and/or technological education, per capita
highschools <- rddxtab(dep = "highschools", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                       lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

# Number of secondary schools for vocational training, per capita
voc_schools <- rddxtab(dep = "voc_schools", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                       lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")
# Number of secondary schools for technical and/or agricultural vocational training, per capita
tech_voc <- rddxtab(dep = "tech_voc", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

nursery_schools <- rddxtab(dep = "nursery_schools", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                           lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

## Demographics
# Number of secondary schools for vocational training, per capita
pop_den <- rddxtab(dep = "pop_area", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                   lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

## Crime
burglary <- rddxtab(dep = "cr_burglary", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

gta <- rddxtab(dep = "cr_gta", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
               lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

property_damage <- rddxtab(dep = "cr_property_damage", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                           lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

## Small local businesses
charcuteries <- rddxtab(dep = "charcuteries", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                        lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

fish_shops <- rddxtab(dep = "fish_shops", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                      lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")

florists <- rddxtab(dep = "florists", fdata = base_data_covars, band = bands10.ik, poly = poly_10.ik, se = "conley", control = con10.ik,
                    lon = "lon", lat = "lat", run = "dist_aslr", threshold = cth, coord = "km",show.controls = "no")



coeff_tab <- data.frame(Estimate = c(workers06$treatment[1:2,2], farmers06$treatment[1:2,2],
                                     artisans06$treatment[1:2,2], executives06$treatment[1:2,2],
                                     intermediate06$treatment[1:2,2], companies11$treatment[1:2,2],
                                     industri11$treatment[1:2,2], building11$treatment[1:2,2],
                                     commercial11$treatment[1:2,2], public11$treatment[1:2,2],
                                     theatre$treatment[1:2,2], multisport$treatment[1:2,2],
                                     athletic$treatment[1:2,2], swimming$treatment[1:2,2],
                                     healthcare_short$treatment[1:2,2], healthcare_medium$treatment[1:2,2],
                                     healthcare_long$treatment[1:2,2], psych$treatment[1:2,2],
                                     post$treatment[1:2,2], serv_house$treatment[1:2,2],
                                     elschools$treatment[1:2,2], highschools$treatment[1:2,2],
                                     voc_schools$treatment[1:2,2], tech_voc$treatment[1:2,2],
                                     pop_den$treatment[1:2,2], dis_adults$treatment[1:2,2],
                                     dis_children$treatment[1:2,2], 
                                     nursery_schools$treatment[1:2,2],
                                     burglary$treatment[1:2,2],
                                     gta$treatment[1:2,2], property_damage$treatment[1:2,2],
                                     charcuteries$treatment[1:2,2], fish_shops$treatment[1:2,2],
                                     florists$treatment[1:2,2]),
                        Std = c(workers06$treatment[1:2,3], farmers06$treatment[1:2,3],
                                artisans06$treatment[1:2,3], executives06$treatment[1:2,3],
                                intermediate06$treatment[1:2,3], companies11$treatment[1:2,3],
                                industri11$treatment[1:2,3], building11$treatment[1:2,3],
                                commercial11$treatment[1:2,3], public11$treatment[1:2,3],
                                theatre$treatment[1:2,3], multisport$treatment[1:2,3],
                                athletic$treatment[1:2,3], swimming$treatment[1:2,3],
                                healthcare_short$treatment[1:2,3], healthcare_medium$treatment[1:2,3],
                                healthcare_long$treatment[1:2,3], psych$treatment[1:2,3],
                                post$treatment[1:2,3], serv_house$treatment[1:2,3],
                                elschools$treatment[1:2,3], highschools$treatment[1:2,3],
                                voc_schools$treatment[1:2,3], tech_voc$treatment[1:2,3],
                                pop_den$treatment[1:2,3],dis_adults$treatment[1:2,3],
                                dis_children$treatment[1:2,3], 
                                nursery_schools$treatment[1:2,3],
                                burglary$treatment[1:2,3],
                                gta$treatment[1:2,3], property_damage$treatment[1:2,3],
                                charcuteries$treatment[1:2,3], fish_shops$treatment[1:2,3],
                                florists$treatment[1:2,3]),
                        Group = as.vector(sapply(varnames,rep,2)),
                        main = rep(c("10 km", "Optimal BW"),34))
coeff_tab$Group <- factor(coeff_tab$Group, levels = rev(varnames))
coeff_tab$main <- factor(coeff_tab$main, levels = c("Optimal BW", "10 km"))


t_stat <- 1.96
coeff_plot <- ggplot(coeff_tab, aes(y = Estimate, x = Group, fill= main))
dodge = position_dodge(width = 0.5)

pdf(paste(outpath_fig,"contemp_covars.pdf", sep = ""), paper = "a4r",width = 20,  height = 10)
coeff_plot + geom_point(colour = "red", size = 2, aes(shape = main), position = dodge) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), 
                position = dodge, width = 0.2) + ylim(-1.5,1.5) +
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Pre-treatment variables") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()


### Specification (coefficient) plots ----

# Referendum 1969

# Specifications included
specnames <- c("Main", "Clustered SE (canton level)", "No controls", 
               "Exclude German-speaking muni.", "Exclude Metz",
               "Exclude German-speaking and Metz", "Control, long. and lat.",
               "Control, historical migration", "Control, language border",
               "2nd degree polynomial")

outcome_vars <- c("yes69", "yes92", "yes05", "avgABO_ph", "reg15VoixExpLREG")

for (var in outcome_vars){
  spec_main <- rddxtab(dep = var, fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                       se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                       run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                       show.controls = "no")$treatment[2,2:3]
  
  spec_cluster <- rddxtab(dep = var, fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                          se = "cluster", control = con10.ik, cluster = "ID_canton",
                          run = "dist_aslr", infer = "se",
                          show.controls = "no")$treatment[2,2:3]
  
  spec_nocont <- rddxtab(dep = var, fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = "no", lon = "lon", lat = "lat", 
                         run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")$treatment[2,2:3]
  
  spec_fr <- rddxtab(dep = var, fdata = compdata1.fr, band = bands10.ik, poly = poly_10.ik, 
                     se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                     run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                     show.controls = "no")$treatment[2,2:3]
  
  spec_metz <- rddxtab(dep = var, fdata = metzagglo.c1, band = bands10.ik, poly = poly_10.ik, 
                       se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                       run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                       show.controls = "no")$treatment[2,2:3]
  
  spec_fr_metz <- rddxtab(dep = var, fdata = metzagglo.c1.fr, band = bands10.ik, poly = poly_10.ik, 
                          se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                          run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                          show.controls = "no")$treatment[2,2:3]
  
  spec_ll <- rddxtab(dep = var, fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                     se = "conley", control = con10_ll, lon = "lon", lat = "lat", 
                     run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                     show.controls = "no")$treatment[2,2:3]
  
  spec_mig <- rddxtab(dep = var, fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                      se = "conley", control = con10_mig, lon = "lon", lat = "lat", 
                      run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                      show.controls = "no")$treatment[2,2:3]
  
  spec_lang <- rddxtab(dep = var, fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                       se = "conley", control = con10_lang, lon = "lon", lat = "lat", 
                       run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                       show.controls = "no")$treatment[2,2:3]
  
  spec_2nd <- rddxtab(dep = var, fdata = base_data, band = bands10.ik, poly = poly2_10.ik, 
                      se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                      run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                      show.controls = "no")$treatment[2,2:3]
  
  
  spec_tab <- data.frame(Specification = specnames, Estimate = c(spec_main[1], spec_cluster[1], 
                                                                 spec_nocont[1], spec_fr[1], spec_metz[1], spec_fr_metz[1],
                                                                 spec_ll[1], spec_mig[1], 
                                                                 spec_lang[1], spec_2nd[1]),
                         Std = c(spec_main[2], spec_cluster[2], spec_nocont[2],
                                 spec_fr[2], spec_metz[2], spec_fr_metz[2],
                                 spec_ll[2], spec_mig[2], 
                                 spec_lang[2], spec_2nd[2]))
  
  spec_tab$Specification <- factor(spec_tab$Specification, 
                                   levels = rev(specnames))
  
  t_stat <- 1.96
  spec_plot <- ggplot(spec_tab, aes(y = Estimate, x = Specification))
  # dodge = position_dodge(width = 0.5) # add this is same spec will have more than 1 estimate
  assign(paste("spec_plot_",var,sep = ""), spec_plot)
  print(paste("Saved spec plot for ", var, sep = ""))
  rm(spec_plot,spec_tab,spec_main,spec_2nd,spec_cluster,spec_fr,spec_lang,spec_ll,spec_mig,spec_nocont)
}


# Saving spec plots as PDF:
pdf(paste(outpath_fig,"spec_plot_69.pdf", sep = ""), paper = "a4r",width = 20,  height = 4)
spec_plot_yes69 + geom_point(colour = "red", size = 3) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), width = 0.2) + 
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Specification") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() + ylim(-5,17.5) + 
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()

pdf(paste(outpath_fig,"spec_plot_92.pdf", sep = ""), paper = "a4r",width = 20,  height = 4)
spec_plot_yes92 + geom_point(colour = "red", size = 3) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), width = 0.2) + 
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Specification") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()

pdf(paste(outpath_fig,"spec_plot_05.pdf", sep = ""), paper = "a4r",width = 20,  height = 4)
spec_plot_yes05 + geom_point(colour = "red", size = 3) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), width = 0.2) + 
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Specification") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()

pdf(paste(outpath_fig,"spec_plot_newspaper.pdf", sep = ""), paper = "a4r",width = 20,  height = 4)
spec_plot_avgABO_ph + geom_point(colour = "red", size = 3) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), width = 0.2) + 
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Specification") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()

pdf(paste(outpath_fig,"spec_plot_regP.pdf", sep = ""), paper = "a4r",width = 20,  height = 4)
spec_plot_reg15VoixExpLREG + geom_point(colour = "red", size = 3) + 
  geom_errorbar(aes(ymin=Estimate-t_stat*Std, ymax=Estimate+t_stat*Std), width = 0.2) + 
  theme_bw(base_size = 20) + labs(y= "Estimated discontinuity",x = "Specification") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15)) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()



### Randomization inference ----

# We loop through pairs of neigbhoring departements and estimate the treatment effect
# at the border

# Create the average of 92 and 05
pairwise_data_b$yes9205 <- (pairwise_data_b$r92_yf + pairwise_data_b$r05_yf)/2

# Create a dummy for whether dep i and dep j are in the same region (ID_1)
pairwise_data_b$main_area <- 0
pairwise_data_b$main_area[pairwise_data_b$reg_name == "ALSACE" | pairwise_data_b$reg_name == "LORRAINE"] <- 1
pairwise_temp <- subset(pairwise_data_b, main_area == 1)

# list of departement codes in the area of analysis
depcodes_main <- as.numeric(names(table(pairwise_temp$code_dept)))

pairwise_data_b$is_reg_main <- 0
pairwise_data_b$is_adj_main <- 0

pairwise_data_b$is_reg_main[pairwise_data_b$code_dept == depcodes_main[1] |
                              pairwise_data_b$code_dept == depcodes_main[2] |
                              pairwise_data_b$code_dept == depcodes_main[3] |
                              pairwise_data_b$code_dept == depcodes_main[4] |
                              pairwise_data_b$code_dept == depcodes_main[5] | 
                              pairwise_data_b$code_dept == depcodes_main[6]] <- 1
pairwise_data_b$is_adj_main[pairwise_data_b$code_dept_adjacent == depcodes_main[1] |
                              pairwise_data_b$code_dept_adjacent == depcodes_main[2] |
                              pairwise_data_b$code_dept_adjacent == depcodes_main[3] |
                              pairwise_data_b$code_dept_adjacent == depcodes_main[4] |
                              pairwise_data_b$code_dept_adjacent == depcodes_main[5] | 
                              pairwise_data_b$code_dept_adjacent == depcodes_main[6]] <- 1

pairwise_data_b$main_area[pairwise_data_b$is_reg_main == 1 | 
                            pairwise_data_b$ is_adj_main == 1] <- 1

# Keep only departements outside of Alsace and Lorraine
pairwise_data <- pairwise_data_b[pairwise_data_b$main_area == 0,]

list_pairs <- as.numeric(names(table(pairwise_data$pair)))

rand_resmat92_10k <- matrix(NA, nrow = length(list_pairs), ncol =4)
rand_resmat05_10k <- matrix(NA, nrow = length(list_pairs), ncol =4)

rand_resmat92_ik <- matrix(NA, nrow = length(list_pairs), ncol =4)
rand_resmat05_ik <- matrix(NA, nrow = length(list_pairs), ncol =4)

rand_resmat9205_10k <- matrix(NA, nrow = length(list_pairs), ncol =4)
rand_resmat9205_ik <- matrix(NA, nrow = length(list_pairs), ncol =4)


for (i in 1:length(list_pairs)){
  temp_pair <- list_pairs[i]
  temp_subsample <- subset(pairwise_data, pair == temp_pair)
  tempRD92 <- rddxtab(dep = "r92_yf", fdata = temp_subsample, band = bands10.ik, 
                      poly = poly_10.ik, se = "conley", 
                      lon = "point_x_meters", lat = "point_y_meters", 
                      run = "distance_pair", infer = "se", 
                      threshold = cth, coord = "km",show.controls = "no")$treatment[,c(2:4,6)]
  rand_resmat92_10k[i,1:4] <- tempRD92[1,]
  rand_resmat92_ik[i,1:4]  <- tempRD92[2,]
  
  tempRD05 <- rddxtab(dep = "r05_yf", fdata = temp_subsample, band = bands10.ik, 
                      poly = poly_10.ik, se = "conley", 
                      lon = "point_x_meters", lat = "point_y_meters", 
                      run = "distance_pair", infer = "se", 
                      threshold = cth, coord = "km",show.controls = "no")$treatment[,c(2:4,6)]
  rand_resmat05_10k[i,1:4] <- tempRD05[1,]
  rand_resmat05_ik[i,1:4]  <- tempRD05[2,]  
  
  tempRD <- rddxtab(dep = "yes9205", fdata = temp_subsample, band = bands10.ik, 
                    poly = poly_10.ik, se = "conley", 
                    lon = "point_x_meters", lat = "point_y_meters", 
                    run = "distance_pair", infer = "se", 
                    threshold = cth, coord = "km",show.controls = "no")$treatment[,c(2:4,6)]
  rand_resmat9205_10k[i,1:4] <- tempRD[1,] 
  rand_resmat9205_ik[i,1:4] <- tempRD[2,]
  print(paste("Saving estimates for pair ", i))  
}

# Saving t-statistics
tval92_10k <- rand_resmat92_10k[,3]
tval92_ik <- rand_resmat92_ik[,3]
tval05_10k <- rand_resmat05_10k[,3]
tval05_ik <- rand_resmat05_ik[,3]
tval9205_10k <- rand_resmat9205_10k[,3]
tval9205_ik <- rand_resmat9205_ik[,3]

# Absolute values of t-statistics
tval92 <- abs((tval92_10k + tval92_ik)/2)
tval05 <- abs((tval05_10k + tval05_ik)/2)
tval9205 <- abs((tval9205_10k + tval9205_ik)/2)

tval92_ik <- abs(tval92_ik)
tval05_ik <- abs(tval05_ik)
tval9205_ik <- abs(tval9205_ik)

# Create data set for the two different categories of RI:
# 1. using ALL dep pairs, combine 10 and ik bandwidth
ggdata_full <- data.frame(est92 = tval92, est05 = tval05, est9205 = tval9205)
# 2. Using ALL dep pairs and only IK bandwidth, separately for 92 and 05 and combo of 92/05
ggdata_ik <- data.frame(est92 = tval92_ik, est05 = tval05_ik, est9205 = tval9205_ik)


# Create the average of 92 and 05 share of yes votes
base_data$yes9205 <- (base_data$yes92+base_data$yes05)/2

# Re-estimate the treatment effect at the treatment border
ref92_wL_RI <- rddxtab(dep = "yes92", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                       se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                       run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                       show.controls = "no")

ref05_wL_RI <- rddxtab(dep = "yes05", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                       se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                       run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                       show.controls = "no")
ref9205_wL_RI <- rddxtab(dep = "yes9205", fdata = base_data, band = bands10.ik, poly = poly_10.ik, 
                         se = "conley", control = con10.ik, lon = "lon", lat = "lat", 
                         run = "dist_aslr", infer = "se", threshold = cth, coord = "km",
                         show.controls = "no")


# We save the ggdata temporarily
save(ggdata_ik,ggdata_full, ref92_wL_RI, ref05_wL_RI, ref9205_wL_RI, 
     file = "..\\Rdata\\randomInf.RData")
load("..\\Rdata\\randomInf.RData")

### We graph the empirical cumulative density functions

# Percentile for the treatment effect (combining 92 and 05 estimates and 10k and IK)
p_9205 <- ecdf(ggdata_full$est9205)(mean(ref9205_wL_RI$treatment[,4]))

bw_size <- 24
ecdf_9205 <- ggplot(ggdata_full,aes(est9205)) 

pdf(paste(outpath_fig,"ecdf9205.pdf", sep = ""), paper = "a4r",width = 20,  height = 10)
ecdf_9205 + stat_ecdf(geom = "point", size = 1.5, pad = FALSE) + theme_bw(base_size = bw_size) + 
  ylab("Cumulative distribution")  +
  geom_vline(xintercept = mean(ref9205_wL_RI$treatment[,4]), colour = "red", size = 1.2) +
  coord_cartesian(xlim = c(-1,6)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) +
  scale_x_continuous("t-statistics at placebo borders",
                     breaks=c(0,2,6,as.numeric(mean(ref9205_wL_RI$treatment[,4]))),
                     labels= c("0", "2", "6", expression(paste(italic(t),"*", sep=""))))
dev.off()


# Percentile for the treatment effect (combining 92 and 05 estimates, only IK)
p_9205_ik <- ecdf(ggdata_ik$est9205)(ref9205_wL_RI$treatment[2,4])

ecdf_9205_ik <- ggplot(ggdata_ik,aes(est9205)) 

pdf(paste(outpath_fig,"ecdf9205_ik.pdf", sep = ""), paper = "a4r",width = 20,  height = 10)
ecdf_9205_ik + stat_ecdf(geom = "point", size = 1.5, pad = FALSE) + theme_bw(base_size = bw_size) + 
  ylab("Cumulative distribution")  +
  geom_vline(xintercept = ref9205_wL_RI$treatment[2,4], colour = "red", size = 1.2) +
  coord_cartesian(xlim = c(-1,9)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) +
  scale_x_continuous("t-statistics at placebo borders",
                     breaks=c(0,2,4,as.numeric(ref9205_wL_RI$treatment[2,4]),8),
                     labels= c("0", "2", "4", expression(paste(italic(t),"*", sep="")),"8"))
dev.off()


p_92 <- ecdf(ggdata_full$est92)(mean(ref92_wL_RI$treatment[,4]))
ecdf_92 <- ggplot(ggdata_full,aes(est92)) 

pdf(paste(outpath_fig,"ecdf92.pdf", sep = ""), paper = "a4r",width = 20,  height = 10)
ecdf_92 + stat_ecdf(geom = "point", size = 1.5, pad = FALSE) + theme_bw(base_size = bw_size) + 
  ylab("Cumulative distribution")  +
  geom_vline(xintercept = mean(ref92_wL_RI$treatment[,4]), colour = "red", size = 1.2) +
  coord_cartesian(xlim = c(-1, 6)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) +
  scale_x_continuous("t-statistics at placebo borders",
                     breaks=c(0,2, mean(ref92_wL_RI$treatment[,4]),4,6),
                     labels= c("0", "2", expression(paste(italic(t),"*", sep="")), "4","6"))
dev.off()

p_05 <- ecdf(ggdata_full$est05)(mean(ref05_wL_RI$treatment[,4]))
ecdf_05 <- ggplot(ggdata_full,aes(est05)) 

pdf(paste(outpath_fig,"ecdf05.pdf", sep = ""), paper = "a4r",width = 20,  height = 10)
ecdf_05 + stat_ecdf(geom = "point", size = 1.5, pad = FALSE) + theme_bw(base_size = bw_size) + 
  ylab("Cumulative distribution")  +
  geom_vline(xintercept = mean(ref05_wL_RI$treatment[,4]), colour = "red", size = 1.2) +
  coord_cartesian(xlim = c(-1, 6)) +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) +
  scale_x_continuous("t-statistics at placebo borders",
                     breaks=c(0,2,mean(ref05_wL_RI$treatment[,4]),4,6),
                     labels= c("0", "2", expression(paste(italic(t),"*", sep="")), "4","6"))
dev.off()


### Survey analysis ----

# Change the name of the treatment variable
oip99_01$treatment <- oip99_01$treat_AL
oip03$treatment <- oip03$treat_AL

oip99_01$dep <- oip99_01$ID_2

# We save data for both the Alsace and Lorraine comparison, and the within Lorraine comparison:
oip99_01_wL <- oip99_01[oip99_01$dep == 54 | oip99_01$dep == 55  | oip99_01$dep == 57,]
oip03_wL <- oip03[oip03$dep == "Meuse" | oip03$dep == "Meurthe-et-Moselle" | oip03$dep == "Moselle",]
oip99_01_wAL <- oip99_01[oip99_01$dep == 67 | oip99_01$dep == 68 | oip99_01$dep == 54 | oip99_01$dep == 55 | oip99_01$dep == 88 | oip99_01$dep == 57,]
oip03_wAL <- oip03[oip03$dep == "Bas-Rhin" | oip03$dep == "Haut-Rhin" | oip03$dep == "Meuse" | oip03$dep == "Meurthe-et-Moselle" | oip03$dep == "Vosges" | oip03$dep == "Moselle",]

# We set the row_dum variable to NA if the respondent lives in Alsace and Lorraine:
oip99_01$row_dum[oip99_01$dep == 67 | oip99_01$dep == 68 | oip99_01$dep == 54 | oip99_01$dep == 55 | oip99_01$dep == 88 | oip99_01$dep == 57] <- NA
oip03$row_dum[oip03$dep == "Moselle" | oip03$dep == "Meurthe-et-Moselle" | oip03$dep == "Meuse" | oip03$dep == "Vosges" | oip03$dep == "Bas-Rhin" | oip03$dep == "Haut-Rhin"] <- NA


# We estimate differences in identity and policy outcomes between treated and control group:

# First, for within Lorraine

# Identity outcomes:
controls <- c("treat_AL", "age", "gender", "employmentstatus", "rs13")
regressors <- paste(paste(controls[1:3], collapse = "+"), " + as.factor(",
                    controls[4], ") + as.numeric(", controls[5],")", sep = "")

depvarsA <-c("attachement_region", "attachement_france")
pr <- 3 # number of decimals

resmatA <- matrix(NA,nrow = length(depvarsA), ncol = 3)

for (i in 1:length(depvarsA)){
  tempreg <- lm(paste("as.numeric(",depvarsA[i], ") ~ ", regressors, sep = ""), oip99_01_wL)
  tempd1  <- oip99_01[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                      c(depvarsA[i], controls)]
  tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
  tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
  #  resmatA[i,1] <- printround(mean(as.numeric(tempd1[tempd1$dep == 54 | tempd1$dep == 55 | tempd1$dep == 88,depvarsA[i]])),pr)
  tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
  resmatA[i,1] <- printround(tempcoef[2,1], pr)
  resmatA[i,2] <- pvalfun(tempcoef[2,4], pr)
  resmatA[i,3] <- nobs(tempreg)
  rm(tempreg, tempd1, tempcoef)
}  

varnames <- c("Feel close to region (Regional identity)", 
              "Feel close to nation (National identity)")
resmatA <- cbind(varnames, resmatA)

# Policy outcomes:
depvarsB <- c("Av_transferOIP2001", "Av_educationOIP2003")
pr <- 3 # number of decimals

resmatB <- matrix(NA,nrow = length(depvarsB), ncol = 3)


tempreg <- lm(paste("Av_transferOIP2001~ ", regressors, sep = ""), data = oip99_01_wL)
tempd1  <- oip99_01[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                    c("Av_transferOIP2001", controls)]
tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
# resmatB[1,1] <- printround(mean(as.numeric(tempd1[tempd1$dep == 54 | tempd1$dep == 55 | tempd1$dep == 88,depvarsB[1]])),pr)
tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
resmatB[1,1] <- printround(tempcoef[2,1], pr)
resmatB[1,2] <- pvalfun(tempcoef[2,4], pr)
resmatB[1,3] <- nobs(tempreg)
rm(tempreg, tempd1, tempcoef)


tempreg <- lm(paste("Av_educationOIP2003 ~ ", regressors, sep = ""), data = oip03_wL)
tempd1  <- oip03[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                 c("Av_educationOIP2003", controls)]
tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
# resmatB[2,1] <- printround(mean(as.numeric(tempd1[tempd1$dep == "Meurthe-et-Moselle" | tempd1$dep == "Meuse" | tempd1$dep == "Vosges",depvarsB[2]]), na.rm = TRUE),pr)
tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
resmatB[2,1] <- printround(tempcoef[2,1], pr)
resmatB[2,2] <- pvalfun(tempcoef[2,4], pr)
resmatB[2,3] <- nobs(tempreg)
rm(tempreg, tempd1, tempcoef)


varnames <- c("In favor: transfer policy competence to region (avg. 10)",
              "Education policy should be set at the regional level (avg. 5)")
resmatB <- cbind(varnames, resmatB)

# Creating TeX-format tables:
print(xtable(rbind(resmatA,resmatB)), floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "oip_panelwL.tex", sep = ""))




### Using survey for all of Alsace and Lorraine
# Identity outcomes:
controls <- c("treat_AL", "age", "gender", "employmentstatus", "rs13")
regressors <- paste(paste(controls[1:3], collapse = "+"), " + as.factor(",
                    controls[4], ") + as.numeric(", controls[5],")", sep = "")

depvarsA <-c("attachement_region", "attachement_france")
pr <- 3 # number of decimals

resmatA <- matrix(NA,nrow = length(depvarsA), ncol = 3)

for (i in 1:length(depvarsA)){
  tempreg <- lm(paste("as.numeric(",depvarsA[i], ") ~ ", regressors, sep = ""), oip99_01_wAL)
  tempd1  <- oip99_01[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                      c(depvarsA[i], controls)]
  tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
  tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
  #  resmatA[i,1] <- printround(mean(as.numeric(tempd1[tempd1$dep == 54 | tempd1$dep == 55 | tempd1$dep == 88,depvarsA[i]])),pr)
  tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
  resmatA[i,1] <- printround(tempcoef[2,1], pr)
  resmatA[i,2] <- pvalfun(tempcoef[2,4], pr)
  resmatA[i,3] <- nobs(tempreg)
  rm(tempreg, tempd1, tempcoef)
}  

varnames <- c("Feel close to region (Regional identity)", 
              "Feel close to nation (National identity)")
resmatA <- cbind(varnames, resmatA)

# Policy outcomes:
depvarsB <- c("Av_transferOIP2001", "Av_educationOIP2003")
pr <- 3 # number of decimals

resmatB <- matrix(NA,nrow = length(depvarsB), ncol = 3)


tempreg <- lm(paste("Av_transferOIP2001~ ", regressors, sep = ""), data = oip99_01_wAL)
tempd1  <- oip99_01[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                    c("Av_transferOIP2001", controls)]
tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
# resmatB[1,1] <- printround(mean(as.numeric(tempd1[tempd1$dep == 54 | tempd1$dep == 55 | tempd1$dep == 88,depvarsB[1]])),pr)
tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
resmatB[1,1] <- printround(tempcoef[2,1], pr)
resmatB[1,2] <- pvalfun(tempcoef[2,4], pr)
resmatB[1,3] <- nobs(tempreg)
rm(tempreg, tempd1, tempcoef)


tempreg <- lm(paste("Av_educationOIP2003 ~ ", regressors, sep = ""), data = oip03_wAL)
tempd1  <- oip03[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                 c("Av_educationOIP2003", controls)]
tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
# resmatB[2,1] <- printround(mean(as.numeric(tempd1[tempd1$dep == "Meurthe-et-Moselle" | tempd1$dep == "Meuse" | tempd1$dep == "Vosges",depvarsB[2]]), na.rm = TRUE),pr)
tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
resmatB[2,1] <- printround(tempcoef[2,1], pr)
resmatB[2,2] <- pvalfun(tempcoef[2,4], pr)
resmatB[2,3] <- nobs(tempreg)
rm(tempreg, tempd1, tempcoef)


varnames <- c("In favor: transfer policy competence to region (avg. 10)",
              "Education policy should be set at regional level (avg. 5)")
resmatB <- cbind(varnames, resmatB)

# Creating TeX-format tables:
print(xtable(rbind(resmatA,resmatB)), floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "oip_panelAL.tex", sep = ""))


### Border regions vs. adjacent neighbours
# We only save slope coefficients and standard errors

# Identity outcomes:
controls <- c("row_dum", "age", "gender", "employmentstatus", "rs13", "dep")
regressors <- paste(paste(controls[1:3], collapse = "+"), " + as.factor(",
                    controls[4], ") + as.numeric(", 
                    controls[5],") + as.factor(",controls[6],")", sep = "")
depvarsA <-c("attachement_region", "attachement_france")

resmatA <- matrix(NA,nrow = length(depvarsA), ncol = 2)

for (i in 1:length(depvarsA)){
  tempreg <- lm(paste("as.numeric(",depvarsA[i], ") ~ ", regressors, sep = ""), oip99_01)
  tempd1  <- oip99_01[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                      c(depvarsA[i], controls)]
  tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
  tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
  tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
  resmatA[i,1] <- tempcoef[2,1]
  resmatA[i,2] <- tempcoef[2,2]
  rm(tempreg, tempcoef)
}  


# Policy outcomes:
depvarsB <- c("Av_transferOIP2001", "Av_educationOIP2003")
resmatB <- matrix(NA,nrow = length(depvarsB), ncol = 2)

tempreg <- lm(paste("Av_transferOIP2001~ ", regressors, sep = ""), data = oip99_01)
tempd1  <- oip99_01[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                    c("Av_transferOIP2001", controls)]
tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
resmatB[1,1] <- tempcoef[2,1]
resmatB[1,2] <- tempcoef[2,2]
rm(tempreg, tempcoef)

tempreg <- lm(paste("Av_educationOIP2003 ~ ", regressors, sep = ""), data = oip03)
tempd1  <- oip03[rownames(cbind(tempreg$fitted.values, tempreg$fitted.values)),
                 c("Av_educationOIP2003", controls)]
tempd1 <- data.frame(surveyoutcome = scale(as.numeric(tempd1[,1])),tempd1[,-1])
tempreg <- lm(paste("surveyoutcome ~ ", regressors, sep = ""), tempd1)
tempcoef <- coeftest(tempreg, vcov = vcovHC(tempreg, type = "HC0")) 
resmatB[2,1] <- tempcoef[2,1]
resmatB[2,2] <- tempcoef[2,2]
rm(tempreg, tempcoef)

varnames <- c()
resmatB <- cbind(varnames, resmatB)

finaltabwL <- rbind(resmatA,resmatB)
varnames <- c("Regional identity", "National identity",
              "Transfer general policy", "Transfer education policy")

# Save the data as a data.frame object
ggplotdata <- data.frame(varnames,finaltabwL)
ggplotdata$varnames <- factor(ggplotdata$varnames, 
                              levels = rev(varnames))
# Save a ggplot object
coeff_plot <- ggplot(ggplotdata, aes(y = X1, x = varnames))

t_stat <- 1.96

# Saving the plot as pdf
pdf(paste(outpath_fig,"oip_coeffplot_placebo.pdf", sep = ""), paper = "a4r",width = 20,  
    height = 20)
coeff_plot + geom_point(colour = "red", size = 3) + 
  geom_errorbar(aes(ymin=X1-t_stat*X2, ymax=X1+t_stat*X2), width = 0.2) + 
  theme_bw(base_size = 26) + labs(y= "Estimated difference",x = "Survey question") +
  geom_hline(yintercept = 0) + scale_shape_manual(values=c(19, 15))+ ylim(-1.5,1.5) +
  theme(legend.position="none") + coord_flip() +
  theme(axis.text.x = element_text(color = "black")) + 
  theme(axis.text.y = element_text(color = "black")) 
dev.off()


### Correlation between European and regional identity
eu_reg_france_nc <- lm(as.numeric(attachement_europe) ~ as.numeric(attachement_region), 
                       data = oip99_01)
eu_reg_france_coeff_nc <- coeftest(eu_reg_france_nc, vcov = vcovHC(eu_reg_france_nc, type = "HC0")) 

eu_reg_france <- lm(as.numeric(attachement_europe) ~ as.numeric(attachement_region) + age + 
                      year + employmentstatus +  gender, data = oip99_01)
eu_reg_france_coeff <- coeftest(eu_reg_france, vcov = vcovHC(eu_reg_france, type = "HC0")) 

eu_reg_wL_nc <- lm(as.numeric(attachement_europe) ~ as.numeric(attachement_region), 
                   data = oip99_01[oip99_01$dep == 57,])
eu_reg_wL_coeff_nc <- coeftest(eu_reg_wL_nc, vcov = vcovHC(eu_reg_france, type = "HC0")) 

eu_reg_wL <- lm(as.numeric(attachement_europe) ~ as.numeric(attachement_region) + age + 
                  year + employmentstatus +  gender, 
                data = oip99_01[oip99_01$dep == 57,])
eu_reg_wL_coeff <- coeftest(eu_reg_wL, vcov = vcovHC(eu_reg_france, type = "HC0")) 

col1 <- cnames2 <- c("Attachement: Region", "", "Obs.", "Controls")
col2 <- c(printround(eu_reg_wL_coeff_nc[2,1],3), 
          pvalround(eu_reg_wL_coeff_nc[2,4], par = "["), nobs(eu_reg_wL_nc), "No")
col3 <- c(printround(eu_reg_wL_coeff[2,1],3), 
          pvalround(eu_reg_wL_coeff[2,4], par = "["), nobs(eu_reg_wL), "Yes")
col4 <- c(printround(eu_reg_france_coeff_nc[2,1],3), 
          pvalround(eu_reg_france_coeff_nc[2,4], par = "["), nobs(eu_reg_france_nc), "No")
col5 <- c(printround(eu_reg_france_coeff[2,1],3), 
          pvalround(eu_reg_france_coeff[2,4], par = "["), nobs(eu_reg_france), "Yes")

eu_reg_tab <- cbind(col1, col2, col3, col4, col5)


# Creating TeX-format tables:
print(xtable(eu_reg_tab), floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "oip2.tex", sep = ""))





### European and regional identity relative to national identity (PIE CHART): ----
# Recode attachement variables:

oip99_01_wAL$reg_identity[oip99_01_wAL$attachement_region == "Disagree strongly"] <- 1
oip99_01_wAL$reg_identity[oip99_01_wAL$attachement_region == "Disagree"] <- 2
oip99_01_wAL$reg_identity[oip99_01_wAL$attachement_region == "Agree"] <- 3
oip99_01_wAL$reg_identity[oip99_01_wAL$attachement_region == "Strongly agree"] <- 4

oip99_01_wAL$euro_identity[oip99_01_wAL$attachement_europe == "Disagree strongly"] <- 1
oip99_01_wAL$euro_identity[oip99_01_wAL$attachement_europe == "Disagree"] <- 2
oip99_01_wAL$euro_identity[oip99_01_wAL$attachement_europe == "Agree"] <- 3
oip99_01_wAL$euro_identity[oip99_01_wAL$attachement_europe == "Strongly agree"] <- 4

oip99_01_wAL$nat_identity[oip99_01_wAL$attachement_france == "Disagree strongly"] <- 1
oip99_01_wAL$nat_identity[oip99_01_wAL$attachement_france == "Disagree"] <- 2
oip99_01_wAL$nat_identity[oip99_01_wAL$attachement_france == "Agree"] <- 3
oip99_01_wAL$nat_identity[oip99_01_wAL$attachement_france == "Strongly agree"] <- 4

# Creating ratio variables: regional to national, and European to national:
oip99_01_wAL$reg_ratio <- oip99_01_wAL$reg_identity/oip99_01_wAL$nat_identity
oip99_01_wAL$euro_ratio <- oip99_01_wAL$euro_identity/oip99_01_wAL$nat_identity 

oip99_01_wAL$mean_control_reg <- mean(oip99_01_wAL[oip99_01_wAL$treatment == 0,"reg_ratio"], na.rm = TRUE)
oip99_01_wAL$mean_control_euro <- mean(oip99_01_wAL[oip99_01_wAL$treatment == 0,"euro_ratio"], na.rm = TRUE)

oip99_01_wAL$larger_reg <- (oip99_01_wAL$reg_ratio >= oip99_01_wAL$mean_control_reg)
oip99_01_wAL$larger_euro <- (oip99_01_wAL$euro_ratio >= oip99_01_wAL$mean_control_euro)

# Saving only individuals who have higher Euro to national identity ratio in the
# treated area, than the average of the control area:
only_stronger_eu <- subset(oip99_01_wAL, larger_euro == TRUE & treatment == 1)

both <- round(100*mean(only_stronger_eu$larger_reg, na.rm = TRUE),2)
onlyeuro <- round(100*(1-mean(only_stronger_eu$larger_reg, na.rm = TRUE)),2)
pie_df <- data.frame(group=c("Both European identity and regional relatively stronger",
                             "Only European identity relatively stronger"),
                     value = c(both,onlyeuro)
)

# Creating pie chart:
pdf(paste(outpath_fig,"euro_regidentity_pie.pdf", sep = ""), paper = "a4r",width = 6,  height = 7)
pie(pie_df$value,border="white", col = c("red", "gray"),
    labels=paste(pie_df$value,"%", sep = ""),
    main = "Identity differences treated compared to control area
(conditional on stating stronger EU identity)")
legend(x = -1.05, y = -0.85,legend=pie_df$group,bty="o",
       fill=c("red", "gray"), border = "white")
dev.off()



### Descriptive statistics ----

### Outcomes
rnd <- 2 # rounding up decimals

varlist <- c("is_aslr","yes69", "yes92", "yes05", "avgABO_ph", "reg15VoixExpLREG")

varnames <- c("Treatment", "Yes 1969", "Yes 1992", "Yes 2005", "Newspaper subscription", 
              "Regionalist parties")

desc.stat <- apply(base_data[,varlist],2,mean, na.rm=TRUE)
desc.outcomes <- cbind(varnames, printround(desc.stat,rnd), 
                       printround(apply(base_data[,varlist],2,sd, na.rm=TRUE),rnd),
                       printround(apply(base_data[,varlist],2,min, na.rm=TRUE),rnd), 
                       printround(apply(base_data[,varlist],2,max, na.rm=TRUE),rnd))

### Save to tex
print(xtable(desc.outcomes),floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "desc_outcomes.tex", sep = ""))


### Controls, main specification
varlist <- con10.20[[1]][1:4]
varnames <- c("Distance to Germany", "Distance to Metz", "Distance to Strasbourg",
              "Distance to Nancy")

desc.stat <- apply(base_data[,varlist],2,mean, na.rm=TRUE)
desc.controls <- cbind(varnames, printround(desc.stat,rnd), 
                       printround(apply(base_data[,varlist],2,sd, na.rm=TRUE),rnd),
                       printround(apply(base_data[,varlist],2,min, na.rm=TRUE),rnd), 
                       printround(apply(base_data[,varlist],2,max, na.rm=TRUE),rnd))

### Save to tex
print(xtable(desc.controls),floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "desc_controls.tex", sep = ""))


### Pre-treatment variables
varlist <- prevars
varnames <- c("Ruggedness", "Elevation", "Wheat", 
              "Potato", "Barley", "Std. Elevation", 
              "Population 1866", "Roads 1800", "Grazing 1860",  "Cropland 1860", 
              "RR stations 1860",  "RR quality 1860")

desc.stat <- apply(base_data[,varlist],2,mean, na.rm=TRUE)
desc.prevars <- cbind(varnames, printround(desc.stat,rnd), 
                      printround(apply(base_data[,varlist],2,sd, na.rm=TRUE),rnd),
                      printround(apply(base_data[,varlist],2,min, na.rm=TRUE),rnd), 
                      printround(apply(base_data[,varlist],2,max, na.rm=TRUE),rnd))

### Save to tex
print(xtable(desc.prevars),floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "desc_prevars.tex", sep = ""))


### Alternative explanations
# First, create some summed variables
base_data_desc <- base_data
base_data_desc$schools <- base_data$elschools + base_data$highschools
base_data_desc$health <- base_data$psych + base_data$healthcare_short + 
  base_data$healthcare_medium + base_data$healthcare_long +
  base_data$serv_house
base_data_desc$voca <- base_data$voc_schools + base_data$tech_voc

varlist <- c("r69_turnout", "r92_turnout", "r05_turnout", "out_wedlock99", 
             "single_parents99", "churches_number", "catholic_dummy", "medinc08", 
             "mean_age06", "school99.bac", "share_workers06", "health", "schools", 
             "voca", "post")
varnames <- c("Turnout 1969", "Turnout 1992", "Turnout 2005", "Unmarried parents",
              "Single parents", "Number of churches", "Catholic church", "Median income",
              "Mean age", "Education", "Occupation", "Healthcare", "Post offices",
              "Schools", "Vocational")

desc.stat <- apply(base_data_desc[,varlist],2,mean, na.rm=TRUE)
desc.contemp <- cbind(varnames, printround(desc.stat,rnd), 
                      printround(apply(base_data_desc[,varlist],2,sd, na.rm=TRUE),rnd),
                      printround(apply(base_data_desc[,varlist],2,min, na.rm=TRUE),rnd), 
                      printround(apply(base_data_desc[,varlist],2,max, na.rm=TRUE),rnd))

### Save to tex
print(xtable(desc.contemp),floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "desc_contemp.tex", sep = ""))



### More variables
varlist <- c("share_workers06", "share_farmers06", "share_artisans06",
             "share_executives06", "share_intermediate06", "companies11",
             "industri11", "building11", "commercial11", "public11", 
             "theatre", "multisport", "athletic", "swimming", "healthcare_short",
             "healthcare_medium", "healthcare_long", "dis_adults", "dis_children",
             "psych", "post", "serv_house", "elschools", "highschools", 
             "voc_schools", "tech_voc", "nursery_schools", "pop_area", 
             "cr_burglary", "cr_gta", "cr_property_damage",
             "charcuteries", "fish_shops", "florists")

varnames <- c("Share workers", "Share farmers", "Share artisans", "Share executives", 
              "Share intermediate", "Companies", "Industrial est.", 
              "Building est.", "Commercial est.", "Public est.", "Theatre rooms", 
              "Multisport fac.", "Athletic centers", "Swimming fac.", "Healthcare (short)",
              "Healthcare (medium)", "Healthcare (long)", "Accom. disabled adults", 
              "Accom. disabled children", "Psychiatric est.",
              "Post offices", "Service houses", "Elementary schools", "Highschools",
              "Vocational training", "Tech. vocational training", "Nursery schools",
              "Population density", "Burglary", "Motor vehicle theft", 
              "Property damage", "Charcuteries", "Fish shops", "Florists")

desc.stat <- apply(base_data[,varlist],2,mean, na.rm=TRUE)
desc.contemp2 <- cbind(varnames, printround(desc.stat,rnd), 
                       printround(apply(base_data[,varlist],2,sd, na.rm=TRUE),rnd),
                       printround(apply(base_data[,varlist],2,min, na.rm=TRUE),rnd), 
                       printround(apply(base_data[,varlist],2,max, na.rm=TRUE),rnd))

### Save to tex
print(xtable(desc.contemp2),floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "desc_contemp2.tex", sep = ""))

# Survey data
varlist <- c("attachement_region", "attachement_france", "Av_transferOIP2001")
varnames <- c("Regional identity", "National identity", "Transfer general policy")

# Converting survey responses to numeric
desc.tab1 <- sapply(oip99_01_wL[,varlist], as.numeric)
desc.tab2 <- as.numeric(oip03_wL[,"Av_educationOIP2003"])

desc.stat <- apply(desc.tab1,2,mean, na.rm=TRUE)
desc.oip1 <- cbind(varnames, printround(desc.stat,rnd), 
                   printround(apply(desc.tab1,2,sd, na.rm=TRUE),rnd),
                   printround(apply(desc.tab1,2,min, na.rm=TRUE),rnd), 
                   printround(apply(desc.tab1,2,max, na.rm=TRUE),rnd))

desc.oip2 <- c("Transfer education policy", printround(c(mean(desc.tab2, na.rm = TRUE), sd(desc.tab2, na.rm = TRUE), 
                                                         min(desc.tab2, na.rm = TRUE), max(desc.tab2, na.rm = TRUE)),rnd))

desc.oip <- rbind(desc.oip1, desc.oip2)

### Save to tex
print(xtable(desc.oip),floating = FALSE,only.contents=TRUE,
      include.rownames = FALSE,include.colnames = FALSE, hline.after=NULL, type = "latex", 
      file = paste(outpath, "desc_oip.tex", sep = ""))




### End ----