##### "The origins of common identity: Evidence from Alsace-Lorraine"
## Authors: Sirus H. Dehdari & Kai Gehring
## R-script for building and cleaning data

## AEA Project ID: openicpsr-120243

# Installing R packages
install.packages(c("foreign", "plyr", "miscTools", "readstata13", "dummies",
                   "lmtest", "sandwich", "xtable", "ggplot2", "corpcor"))

# Loading packages
library(foreign)
library(plyr) # To use function "rename"
library(miscTools) # for instertRow command
library(readstata13) # To read Stata13 dta-files
library(dummies)


### Import commune level data:

# Importing the final version of the merged data (merged in Stata\do-files\)
td <- read.dta13("..\\Stata_data\\processed data\\AlsaceLorraine.dta")
tdvar <- cbind(names(td),attr(td, "var.label"))

###### INITIAL CLEANING: Removing observations in Belfort, removing obs with pop = 0, and obs with missing info on location
td_bel <- td[td$dep_name != "TERRITOIRE DE BELFORT",] # Removes all obs. in Belfort

# The running variable (distance to border) is normalized to zero at the border and positive for
# all treated communes. We focus only on French municipalities
tdfra <- td_bel[td_bel$is_fra == 1,]

# Removing all variables with population = 0.
tdfra <- tdfra[tdfra$P11_POP > 0,]


# For completeness, we remove all observations with missing information on location.
# whichNA <- which(is.na(tdfra$is_as) == TRUE | is.na(tdfra$is_lr) == TRUE | 
#           is.na(tdfra$is_med_aslr) == TRUE)
# tdfra <- tdfra[-(whichNA),]

nobfra <- dim(tdfra)[1]

rm(td,td_bel)


### NOTICE: Since original data is in meters, I've divided all treatment-distance measures with 1k
### However, this can be changed by simply changing 'mes' to 1
mes <- 1000

# Normalizing distance to border between French and (former) German part of Alsace-Lorraine:
dist_aslr <- tdfra$dist_b_ASLR_FRA/mes
tdfra$distance_robust_border <- tdfra$distance_robust_border/mes

# Normalizing distance to Maginot line:
tdfra$distance_maginot <- tdfra$distance_maginot/mes

### Converting road distance to kilometers
tdfra$road_length <- tdfra$road_length/1000

# Converting population to 100s, and dividing the wheat variable by 100:
tdfra$ra_wheat_int_rf_resample <- tdfra$ra_wheat_int_rf_resample/100
tdfra$sui_wpo <- tdfra$sui_wpo/100
tdfra$sui_brl <- tdfra$sui_brl/100
tdfra$p1866 <- tdfra$p1866/100


###### Creating running variables for distance to borders ######
# Create a dummy taking the value 1 for communes in either Alsace or Lorraine (German part)
tdfra$is_aslr <- tdfra$is_as + tdfra$is_lr

# Creating a dummy taking the value 1 for all communes in the non-annexed part of A-L
tdfra$is_non <- 0
tdfra$is_non[tdfra$is_med_aslr == 1 & tdfra$is_aslr == 0] <- 1

# Creating a running variable for distance to the former French-German border, with negative values for non-annexed part.
for (i in 1:nobfra){
  if (is.na(tdfra$is_aslr[i]) == FALSE){
    if (tdfra$is_aslr[i] == 0) dist_aslr[i] <- dist_aslr[i]*(-1)
  }
}
rm(i)

# Creating a running variable for distance to the "mega border", with negative values for adjacent neighbors:
for (i in 1:nobfra){
  if (is.na(tdfra$row_dum[i]) == FALSE){
    if (tdfra$row_dum[i] == 0) tdfra$distance_robust_border[i] <- tdfra$distance_robust_border[i]*(-1)
  }
}
rm(i)

tdfra$dist_b_LANGUAGE <- tdfra$dist_b_LANGUAGE/mes


# Creating a running variable for distance to the language border, with negative values for the francophone part.
for (i in 1:nobfra){
  if (is.na(tdfra$francophone[i]) == FALSE){
    if (tdfra$francophone[i] == 1) tdfra$dist_b_LANGUAGE[i] <- tdfra$dist_b_LANGUAGE[i]*(-1)
  }
}
rm(i)

# Next, we create a running variable for the border between France and (all of) Alsace-Lorraine:
tdfra$dist_b_MED_ASLR_FRA <- tdfra$dist_b_MED_ASLR_FRA/mes

for (i in 1:nobfra){
  if (is.na(tdfra$is_med_aslr[i]) == FALSE){
    if (tdfra$is_med_aslr[i] == 0) tdfra$dist_b_MED_ASLR_FRA[i] <- tdfra$dist_b_MED_ASLR_FRA[i]*(-1)
  }
}
rm(i)

# Creating the running variable for the border between old Moselle and old Meurthe:
tdfra$is_moselle <- tdfra$FE_moselle
tdfra[!is.na(tdfra$FE_meurthe) & !is.na(tdfra$FE_moselle) & tdfra$FE_meurthe == 0 & tdfra$FE_moselle == 0, "is_moselle"] <- NA

tdfra$dist_old_border <- tdfra$dist_old_border/mes

for (i in 1:nobfra){
  if (is.na(tdfra$is_moselle[i]) == FALSE){
    if (tdfra$is_moselle[i] == 0) tdfra$dist_old_border[i] <- tdfra$dist_old_border[i]*(-1)
  }
}
rm(i)


### Normalizing distances used as control variables:

tdfra$dist_c_METZ <- tdfra$dist_c_METZ/mes
tdfra$dist_c_STRASBOURG <- tdfra$dist_c_STRASBOURG/mes
tdfra$dist_c_BRUSSELS <- tdfra$dist_c_BRUSSELS/mes
tdfra$dist_b_LUX_FRA <- tdfra$dist_b_LUX_FRA/mes
tdfra$dist_c_NANCY <- tdfra$dist_c_NANCY/mes
tdfra$dist_ger <- tdfra$dist_b_ASLR_DEU/mes
tdfra$distance_national_border <- tdfra$distance_national_border/mes

# And, for the descriptive statistics:
tdfra$dist_b_ASLR_FRA <- tdfra$dist_b_ASLR_FRA/mes

# We add the running variable for the distance to the, within AsLR, French-German border
tdfra <- cbind(tdfra, dist_aslr)

###### Creating turnout variables ######
# Creating variables for the share of absent voters, 1992 and 2005 referendum and 2007 pres.


tdfra$r92_turnout <- (1 - tdfra$r92_abs/tdfra$r92_reg)*100
tdfra$r05_turnout <- (1 - tdfra$r05_abs/tdfra$r05_reg)*100
# tdfra$p07_turnout <- (1 -tdfra$p07a_abs/tdfra$p07a_reg)*100


###
# For some reason, the two variables r92yf and r05yf keep changing name to r92_yf and r05_yf.
# Therefore, we create versions with both names:
# tdfra$r92yf <- tdfra$r92_yf
# tdfra$r05yf <- tdfra$r05_yf
# tdfra$r92_yf <- tdfra$r92yf
# tdfra$r05_yf <- tdfra$r05yf
###

### Creating measure of share of votes on right and left wing parties for municipal election 2001, first and second round.

# Remove?
# tdfra$m01a_fright = tdfra$m01a_5/tdfra$m01a_votes
# tdfra$m01b_fright = tdfra$m01b_5/tdfra$m01b_votes
# tdfra$m01a_right = tdfra$m01a_4/tdfra$m01a_votes
# tdfra$m01b_right = tdfra$m01b_4/tdfra$m01b_votes

# tdfra$m01a_fleft = tdfra$m01a_1/tdfra$m01a_votes
# tdfra$m01b_fleft = tdfra$m01b_1/tdfra$m01b_votes

###### Creating variables for disc. checks on covariates ######
### Creating variables for mean age:
tdfra$mean_age06 <- 7*tdfra$P06_POP0014/tdfra$P06_POP + 22*tdfra$P06_POP1529/tdfra$P06_POP + 
  37*tdfra$P06_POP3044/tdfra$P06_POP + 52*tdfra$P06_POP4559/tdfra$P06_POP + 
  67*tdfra$P06_POP6074/tdfra$P06_POP + 82*tdfra$P06_POP7589/tdfra$P06_POP + 
  90*tdfra$P06_POP90P/tdfra$P06_POP


##### Creating education variables:
# Share with 10th grade as highest attainment
tdfra$school99.dipl <- tdfra$P99_NSCOL15P_DIPL0/(tdfra$P99_POP1517 + tdfra$P99_POP1824 + tdfra$P99_POP2529 + tdfra$P99_POP30P)

# Share with highschool degree BAC as highest attainment
tdfra$school99.bac <- tdfra$P99_NSCOL15P_BAC/(tdfra$P99_POP1517 + tdfra$P99_POP1824 + tdfra$P99_POP2529 + tdfra$P99_POP30P)

# Share 18 years or older still in education
tdfra$uni99 <- (tdfra$P99_SCOL1824 + tdfra$P99_SCOL2529 + tdfra$P99_SCOL30P)/(tdfra$P99_POP1824 + 
                                                                                tdfra$P99_POP2529 + tdfra$P99_POP30P)

##### Occupation/employment variables:

# Share of workers, 15 years and older
tdfra$share_workers06 <- tdfra$C06_POP15P_CS6/tdfra$C06_POP15P

# Share of farmers, 15 years and older
tdfra$share_farmers06 <- tdfra$C06_POP15P_CS1/tdfra$C06_POP15P

# Share of artisans, 15 years and older
tdfra$share_artisans06 <- tdfra$C06_POP15P_CS2/tdfra$C06_POP15P

# Share of executives, 15 years and older
tdfra$share_executives06 <- tdfra$C06_POP15P_CS3/tdfra$C06_POP15P

# Share of intermediate professions, 15 years and older
tdfra$share_intermediate06 <- tdfra$C06_POP15P_CS4/tdfra$C06_POP15P

# Share of employees, 15 years and older
tdfra$share_employees06 <- tdfra$C06_POP15P_CS5/tdfra$C06_POP15P


### Creating measure for population above 15 years, in thousands:
# Remove?
#tdfra$pop15thousands <- tdfra$C11_POP15P/1000


###### Some industry variables have Inf as value: we replace these with NA.
tdfra$companies11 <- tdfra$ENNTOT11
tdfra$companies11[tdfra$companies11 == Inf] <- NA

# Number of commercial, transport and miscellaneous services establishments
tdfra$commercial11 <- tdfra$ETNGU11
tdfra$commercial11[tdfra$commercial11 == Inf] <- NA


# Creating variables for the number of people living in the same mun, same region,
# or outside the region, the year before 2011 (data is from 2011)
# Remove??
# tdfra$same_mun2011 <- 100*(tdfra$P11_POP01P_IRAN1 + tdfra$P11_POP01P_IRAN2)/tdfra$P11_POP01P
# tdfra$same_reg2011 <- 100*(tdfra$P11_POP01P_IRAN1 + tdfra$P11_POP01P_IRAN2 + tdfra$P11_POP01P_IRAN3 + tdfra$P11_POP01P_IRAN4)/tdfra$P11_POP01P
# tdfra$other_reg2011 <- 100*(tdfra$P11_POP01P_IRAN5 + tdfra$P11_POP01P_IRAN6 + tdfra$P11_POP01P_IRAN7)/tdfra$P11_POP01P

tdfra <- rename(tdfra, c("NB_C104" = "elschools", "NB_C301" = "highschools",
                         "NB_C303" = "tech_voc", "NB_C302" = "voc_schools",
                         "NB_A116" = "serv_house", "NB_A112" = "perm_empl",
                         "NB_A206" = "post", "NB_D104" = "psych", "NB_D103" = "healthcare_long",
                         "NB_D102" = "healthcare_medium", "NB_D101" = "healthcare_short",
                         "NB_F101_NB_AIREJEU" = "swimming", "NB_F107_NB_AIREJEU" = "athletic",
                         "NB_F111_NB_AIREJEU" = "multisport", "NB_F302_NB_SALLES" = "theatre",
                         "ENNOQ11" = "public11", "ETNCFZ11" = "building11",
                         "ETNBE11" = "industri11", "point_x_meters" = "lon", "point_y_meters" = "lat", 
                         "r92_yf" = "yes92", "r05_yf" = "yes05",
                         "RFMQ208" = "medinc08", "RFMMO08" = "meaninc08", "RFMGI08"="gini08", 
                         "er_rug" = "rugged", "sui_wpo" = "potato_int_rf", "sui_whe"= "wheat_int_irr", 
                         "ra_wheat_int_rf_resample" = "wheat_int_rf", "P11_POP01P" = "pop2011",
                         "sui_brl"= "barley_int_irr", "er_elev" = "elevation", 
                         "st_dev_elev" = "elevation_std", "NB_D601" = "dis_children",
                         "NB_D603" = "dis_adults","NB_B204" = "charcuteries","NB_B206" = "fish_shops",
                         "NB_B312" = "florists", "NB_C101" = "nursery_schools"))




tdfra$medinc08 <- tdfra$medinc08/1000
tdfra$avgABO_ph <- tdfra$avgABO_ph*100

# Re-scaling the cultural variables (changing share to percent):
tdfra$out_wedlock90 <- 100*tdfra$out_wedlock90
tdfra$out_wedlock99 <- 100*tdfra$out_wedlock99
tdfra$single_parents90 <- 100*tdfra$single_parents90
tdfra$single_parents99 <- 100*tdfra$single_parents99



# For the communes in Alsace and Lorraine, we set row_dum to NA:
tdfra$row_dum[tdfra$dep_name == "MOSELLE" | tdfra$dep_name == "MEURTHE-ET-MOSELLE" | tdfra$dep_name == "MEUSE" | tdfra$dep_name == "VOSGES" | tdfra$dep_name == "HAUT-RHIN" | tdfra$dep_name == "BAS-RHIN"] <- NA

tdfra$distance_robust_border[is.na(tdfra$row_dum)] <- NA

# Remove?
# tdfra$test <- 100*tdfra$reg15VoixLREG/tdfra$reg15Votants

keep <- c("insee_code","mun_name", "dep_name", "ID_1","ID_2", "ID_3", "ID_4", "ID_5", 
          "ID_canton", "dist_old_border",
          "dist_b_MED_ASLR_FRA", "dist_c_METZ", "dist_c_STRASBOURG", "dist_c_NANCY", 
          "dist_c_BRUSSELS", "dist_b_LUX_FRA", "dist_b_ASLR_FRA", "dist_aslr", 
          "dist_b_LANGUAGE", "is_aslr", "is_non", 
          "francophone", "rugged", "potato_int_rf", "wheat_int_irr", "wheat_int_rf", 
          "r92_turnout", "r05_turnout", "dist_ger", "lat", "lon", 
          "yes92", "yes05","medinc08", "meaninc08", "pop_area", "share_workers06", 
          "ra_elevation_raster", "rstd_elevation_raster", "mean_age06", "companies11", 
          "school99.dipl", "school99.bac", "uni99", "share_farmers06", "share_artisans06", 
          "share_executives06", "share_intermediate06", "share_employees06", "industri11", 
          "building11", "commercial11", "public11", "theatre", "multisport", "athletic", 
          "swimming", "healthcare_short", "healthcare_medium", "healthcare_long", "psych", 
          "post", "perm_empl", "serv_house", "voc_schools", "tech_voc", "highschools", 
          "elschools", "Other_tweet", "France_tweet", "Germany_tweet", "Population_1916", 
          "Population_1926", "Population_1936","Population_1946", "pop2011", "avgABO_ph",
          "nrpointofsale", "avgABO","avgVNOABO",
          "reg15VotIns", "reg15VoixInsLREG", "reg15VoixExpLREG", "close_mid", "close_south", 
          "close_north", "oui_1969", "non_1969", "inscrits_1969", "barley_int_irr",
          "votants_1969", "exprimes_1969", "communes_1969", "row_dum", "row_dum2", 
          "distance_robust_border", "distance_national_border", "p1866", "popdens_1866",
          "elevation", "elevation_std", "dist_old_border",
          "lorr_seg_north", "lorr_seg_middle", "lorr_seg_south", "road_length",
          "river_length", "LU_grazing_1860", "LU_cropland_1860", "gare_1860", "hie_1860",
          "out_wedlock90", "out_wedlock99", "single_parents90", "single_parents99",
          "catholic_dummy", "churches_number", "maginot_right", "distance_maginot",
          "cr_burglary", "cr_gta", "cr_property_damage", "dis_children", "dis_adults", 
          "charcuteries", "fish_shops", "florists", "nursery_schools")




tdfra$lon <- tdfra$lon/1000
tdfra$lat <- tdfra$lat/1000

tdfra <- tdfra[,keep]

# Creating yes share and turnout for 1969:
tdfra$yes69 <- 100*tdfra$oui_1969/tdfra$votants_1969
tdfra$yes69[tdfra$yes69 > 100] <- NA
tdfra$r69_turnout <- 100*tdfra$votants_1969/tdfra$inscrits_1969
tdfra$r69_turnout[tdfra$r69_turnout > 100] <- NA

# Creating a dummy for railroad quality:
tdfra$rrqual <- tdfra$hie_1860 == 1
tdfra$rrqual[tdfra$rrqual == TRUE] <- 1
tdfra$rrqual[tdfra$rrqual == FALSE] <- 0


# Computing population differences from 1916 to 1946
tdfra$Popdiff_16_26 <- 100*(tdfra$Population_1926 - tdfra$Population_1916)/tdfra$Population_1916
tdfra$Popdiff_26_36 <- 100*(tdfra$Population_1936 - tdfra$Population_1926)/tdfra$Population_1926
tdfra$Popdiff_36_46 <- 100*(tdfra$Population_1946 - tdfra$Population_1936)/tdfra$Population_1936
tdfra$Popdiff_16_46 <- 100*(tdfra$Population_1946 - tdfra$Population_1916)/tdfra$Population_1916


# We save the data as a dta-file:
# write.dta(tdfra, "..\\..\\Rdata\\maindataFRA.dta") 
save(tdfra, file = "..\\Rdata\\maindataFRA.RData")
save(tdvar, file = "..\\Rdata\\labels.Rdata")


##### Subsetting data ----

# We remove all observations with population density equal to 0
# tdfra <- subset(tdfra, tdfra$pop_area != 0)

# Creating interaction between longitude and latitude
tdfra$lonlat <- tdfra$lon*tdfra$lat

# p.data consists of communes within 10k from the old French-German border
p.data <- tdfra[abs(tdfra$dist_aslr) < 10,]

# Data set with only communes in Alsace AND Lorraine
aldata <- subset(tdfra, tdfra$is_non == 1 | tdfra$is_aslr == 1)

### Creating border segments based on latitude, only within Alsace AND Lorraine
subtemp <- subset(aldata,abs(aldata$dist_aslr) < 20)$lat
totlength <- max(subtemp) - min(subtemp)


# Compdata1 comprises only of communes within Lorraine
compdata1 <- tdfra[tdfra$dep_name == "MOSELLE" | tdfra$dep_name == "MEURTHE-ET-MOSELLE" | tdfra$dep_name == "MEUSE",]
# compdata3 <- tdfra[tdfra$dep_name == "VOSGES" | tdfra$dep_name == "HAUT-RHIN" | tdfra$dep_name == "BAS-RHIN",]

# In compdata1, we replace all NAs for the subscriber data with 0
compdata1[is.na(compdata1$nrpointofsale),"nrpointofsale"] <- 0
compdata1[is.na(compdata1$avgABO_ph),"avgABO_ph"] <- 0

# Excluding Metz
mossdata <- tdfra[tdfra$dep_name == "MOSELLE" | tdfra$dep_name == "MEURTHE-ET-MOSELLE" | tdfra$dep_name == "MEUSE",]
metzagglo.c1 <- mossdata[mossdata$mun_name != "AMNEVILLE" & mossdata$mun_name != "ANCY-SUR-MOSELLE" & mossdata$mun_name != "ARS-SUR-MOSELLE" & mossdata$mun_name != "AUGNY" & mossdata$mun_name != "CHATEL-SAINT-GERMAIN" & mossdata$mun_name != "CLOUANGE" & mossdata$mun_name != "DORNOT" & mossdata$mun_name != "FEVES" & mossdata$mun_name != "GANDRANGE" & mossdata$mun_name != "HAGONDANGE" & mossdata$mun_name != "JOUY-AUX-ARCHES" & mossdata$mun_name != "JUSSY" & mossdata$mun_name != "LA MAXE" & mossdata$mun_name != "LE BAN-SAINT-MARTIN" & mossdata$mun_name != "LESSY" & mossdata$mun_name != "LONGEVILLE-LES-METZ" & mossdata$mun_name != "LORRY-LES-METZ" & mossdata$mun_name != "MAIZIERES-LES-METZ" & mossdata$mun_name != "MARLY" & mossdata$mun_name != "METZ" & mossdata$mun_name != "MONDELANGE" & mossdata$mun_name != "MONTIGNY-LES-METZ" & mossdata$mun_name != "MOULINS-LES-METZ" & mossdata$mun_name != "MOYEUVRE-GRANDE" & mossdata$mun_name != "MOYEUVRE-PETITE " & mossdata$mun_name != "PIERREVILLERS" & mossdata$mun_name != "PLAPPEVILLE" & mossdata$mun_name != "RICHEMONT" & mossdata$mun_name != "ROMBAS" & mossdata$mun_name != "ROSSELANGE" & mossdata$mun_name != "ROZERIEULLES" & mossdata$mun_name != "SAINT-RUFFINE" & mossdata$mun_name != "SAINT-JULIEN-LES-METZ" & mossdata$mun_name != "SAULNY" & mossdata$mun_name != "SCY-CHAZELLES" & mossdata$mun_name != "SEMECOURT" & mossdata$mun_name != "TALANGE" & mossdata$mun_name != "VANTOUX" & mossdata$mun_name != "VAUX" & mossdata$mun_name != "VITRY-SUR-ORNE" & mossdata$mun_name != "WOIPY",]

# Excluding Metz and German-speaking communes
metzagglo.c1.fr <- subset(metzagglo.c1, metzagglo.c1$francophone == 1)

# Creating a dataset where we remove all communes in the annexed part from the within Alsace and Lorraine data
noannexdata <-subset(aldata, aldata$is_aslr == 0)
# And, one where we only have communes in the annexed part:
annexdata <- subset(tdfra, tdfra$is_aslr == 1)

# Only French-speaking communes
francdata <- subset(tdfra, tdfra$francophone == 1)

# Departement-specific comparisons, only French-speaking
compdata1.fr <- subset(compdata1, compdata1$francophone == 1)

# Removing all communes 5 kilometer from Metz
metzdata10 <- aldata[aldata$dist_c_METZ > 5,]
metzdata10.c1 <- metzdata10[metzdata10$dep_name == "MOSELLE" | metzdata10$dep_name == "MEURTHE-ET-MOSELLE" | metzdata10$dep_name == "MEUSE",]
metzdata10.c1.fr <- subset(metzdata10.c1, metzdata10.c1$francophone == 1)

# Removing all communes 10 kilometer from Metz
metzdata15 <- aldata[aldata$dist_c_METZ > 10,]
metzdata15.c1 <- metzdata15[metzdata15$dep_name == "MOSELLE" | metzdata15$dep_name == "MEURTHE-ET-MOSELLE" | metzdata15$dep_name == "MEUSE",]
metzdata15.c1.fr <- subset(metzdata15.c1, metzdata15.c1$francophone == 1)


# Creating Twitter data for within Lorraine (shares of tweets)
compdata1$Germany_tweet_share <- 100*compdata1$Germany_tweet/(compdata1$Germany_tweet+compdata1$France_tweet + compdata1$Other_tweet)
compdata1$France_tweet_share <- 100*compdata1$France_tweet/(compdata1$Germany_tweet+compdata1$France_tweet + compdata1$Other_tweet)

# Creating data for Moselle only
# moselle_data <- compdata1[compdata1$dep_name == "MOSELLE",]
# meurthe_data <- compdata1[compdata1$dep_name == "MEURTHE-ET-MOSELLE",]

save(tdfra, compdata1, compdata1.fr, aldata, annexdata, francdata, 
     metzagglo.c1, metzagglo.c1.fr, metzdata10, metzdata10.c1, metzdata10.c1.fr, metzdata15,
     metzdata15.c1, metzdata15.c1.fr, mossdata, noannexdata,
     file = "..\\Rdata\\subsetdata.RData")
